/* topbar.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from topbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_TOPBAR_PAGE (boxes_topbar_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_WIZARD_PAGE (boxes_wizard_page_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
typedef struct _BoxesDisplayPagePrivate BoxesDisplayPagePrivate;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	BOXES_TOPBAR_PAGE_COLLECTION,
	BOXES_TOPBAR_PAGE_SELECTION,
	BOXES_TOPBAR_PAGE_WIZARD,
	BOXES_TOPBAR_PAGE_PROPERTIES,
	BOXES_TOPBAR_PAGE_DISPLAY
} BoxesTopbarPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesTopbar {
	GtkStack parent_instance;
	BoxesTopbarPrivate * priv;
	GtkButton* wizard_cancel_btn;
	GtkButton* wizard_back_btn;
	GtkButton* wizard_continue_btn;
	GtkButton* wizard_create_btn;
	gchar* _status;
};

struct _BoxesTopbarClass {
	GtkStackClass parent_class;
};

struct _BoxesTopbarPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	GtkButton* props_back_btn;
	GtkButton* search_btn;
	GtkButton* search2_btn;
	GtkButton* select_btn;
	GtkButton* back_btn;
	GtkImage* back_image;
	GtkButton* new_btn;
	GtkMenuButton* selection_menu_button;
	GtkHeaderBar* collection_toolbar;
	BoxesDisplayToolbar* display_toolbar;
	GtkHeaderBar* props_toolbar;
	GtkImage* props_back_image;
	GBinding* props_name_bind;
	BoxesTopbarPage _page;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef enum  {
	BOXES_WIZARD_PAGE_INTRODUCTION,
	BOXES_WIZARD_PAGE_SOURCE,
	BOXES_WIZARD_PAGE_PREPARATION,
	BOXES_WIZARD_PAGE_SETUP,
	BOXES_WIZARD_PAGE_REVIEW,
	BOXES_WIZARD_PAGE_LAST
} BoxesWizardPage;

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesDisplayPage {
	GtkBox parent_instance;
	BoxesDisplayPagePrivate * priv;
	BoxesDisplayToolbar* toolbar;
};

struct _BoxesDisplayPageClass {
	GtkBoxClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};


static gpointer boxes_topbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;
extern BoxesAppWindow* boxes_app_window;
static BoxesUIIface* boxes_topbar_boxes_ui_parent_iface = NULL;

GType boxes_topbar_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
#define BOXES_TOPBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_TOPBAR, BoxesTopbarPrivate))
enum  {
	BOXES_TOPBAR_DUMMY_PROPERTY,
	BOXES_TOPBAR_PREVIOUS_UI_STATE,
	BOXES_TOPBAR_UI_STATE,
	BOXES_TOPBAR_STATUS,
	BOXES_TOPBAR_PROPERTIES_TITLE,
	BOXES_TOPBAR_PAGE
};
void boxes_topbar_click_back_button (BoxesTopbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_wizard_page_get_type (void) G_GNUC_CONST;
BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self);
void boxes_topbar_click_forward_button (BoxesTopbar* self);
void boxes_topbar_click_cancel_button (BoxesTopbar* self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
void boxes_topbar_setup_ui (BoxesTopbar* self);
static void __lambda109_ (BoxesTopbar* self);
void boxes_topbar_set_page (BoxesTopbar* self, BoxesTopbarPage value);
static void ___lambda109__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_topbar_update_select_btn (BoxesTopbar* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
static void _boxes_topbar_update_select_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_topbar_update_select_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void boxes_topbar_update_selection_label (BoxesTopbar* self);
static void boxes_topbar_update_search_btn (BoxesTopbar* self);
static void _boxes_topbar_update_search_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_topbar_update_search_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
GList* boxes_app_get_selected_items (BoxesApp* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_topbar_ui_state_changed (BoxesTopbar* self);
static void boxes_topbar_on_new_btn_clicked (BoxesTopbar* self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
static void _boxes_topbar_on_new_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_topbar_on_back_btn_clicked (BoxesTopbar* self);
static void _boxes_topbar_on_back_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_topbar_on_select_btn_clicked (BoxesTopbar* self);
static void _boxes_topbar_on_select_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_topbar_on_cancel_btn_clicked (BoxesTopbar* self);
static void _boxes_topbar_on_cancel_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_topbar_on_props_back_btn_clicked (BoxesTopbar* self);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _boxes_topbar_on_props_back_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
BoxesTopbar* boxes_topbar_new (void);
BoxesTopbar* boxes_topbar_construct (GType object_type);
const gchar* boxes_topbar_get_status (BoxesTopbar* self);
void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value);
void boxes_topbar_set_properties_title (BoxesTopbar* self, const gchar* value);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
BoxesTopbarPage boxes_topbar_get_page (BoxesTopbar* self);
static GObject * boxes_topbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_topbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_topbar___lambda126_ (BoxesTopbar* self);
static void __boxes_topbar___lambda126__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_topbar_finalize (GObject* obj);
static void _vala_boxes_topbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_topbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const gchar* BOXES_TOPBAR_page_names[5] = {"collection", "selection", "wizard", "properties", "display"};

GType boxes_topbar_page_get_type (void) {
	static volatile gsize boxes_topbar_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_topbar_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_TOPBAR_PAGE_COLLECTION, "BOXES_TOPBAR_PAGE_COLLECTION", "collection"}, {BOXES_TOPBAR_PAGE_SELECTION, "BOXES_TOPBAR_PAGE_SELECTION", "selection"}, {BOXES_TOPBAR_PAGE_WIZARD, "BOXES_TOPBAR_PAGE_WIZARD", "wizard"}, {BOXES_TOPBAR_PAGE_PROPERTIES, "BOXES_TOPBAR_PAGE_PROPERTIES", "properties"}, {BOXES_TOPBAR_PAGE_DISPLAY, "BOXES_TOPBAR_PAGE_DISPLAY", "display"}, {0, NULL, NULL}};
		GType boxes_topbar_page_type_id;
		boxes_topbar_page_type_id = g_enum_register_static ("BoxesTopbarPage", values);
		g_once_init_leave (&boxes_topbar_page_type_id__volatile, boxes_topbar_page_type_id);
	}
	return boxes_topbar_page_type_id__volatile;
}


void boxes_topbar_click_back_button (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	switch (_tmp2_) {
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 424 "topbar.c"
		{
			GtkButton* _tmp3_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp3_ = self->priv->props_back_btn;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_button_clicked (_tmp3_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 433 "topbar.c"
		}
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_CREDS:
#line 437 "topbar.c"
		{
			GtkButton* _tmp4_ = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp4_ = self->priv->back_btn;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_button_clicked (_tmp4_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 446 "topbar.c"
		}
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 450 "topbar.c"
		{
			BoxesAppWindow* _tmp5_ = NULL;
			BoxesWizard* _tmp6_ = NULL;
			BoxesWizardPage _tmp7_ = 0;
			BoxesWizardPage _tmp8_ = 0;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp5_ = boxes_app_window;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp6_ = _tmp5_->wizard;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp7_ = boxes_wizard_get_page (_tmp6_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp8_ = _tmp7_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			if (_tmp8_ != BOXES_WIZARD_PAGE_INTRODUCTION) {
#line 466 "topbar.c"
				GtkButton* _tmp9_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
				_tmp9_ = self->wizard_back_btn;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
				gtk_button_clicked (_tmp9_);
#line 472 "topbar.c"
			}
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 476 "topbar.c"
		}
		default:
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 481 "topbar.c"
	}
}


void boxes_topbar_click_forward_button (BoxesTopbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesWizard* _tmp1_ = NULL;
	BoxesWizardPage _tmp2_ = 0;
	BoxesWizardPage _tmp3_ = 0;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_window;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = _tmp0_->wizard;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = boxes_wizard_get_page (_tmp1_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	if (_tmp3_ != BOXES_WIZARD_PAGE_REVIEW) {
#line 503 "topbar.c"
		GtkButton* _tmp4_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp4_ = self->wizard_continue_btn;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		gtk_button_clicked (_tmp4_);
#line 509 "topbar.c"
	}
}


void boxes_topbar_click_cancel_button (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	switch (_tmp2_) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 530 "topbar.c"
		{
			BoxesApp* _tmp3_ = NULL;
			gboolean _tmp4_ = FALSE;
			gboolean _tmp5_ = FALSE;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp3_ = boxes_app_app;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp4_ = boxes_app_get_selection_mode (_tmp3_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp5_ = _tmp4_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			if (_tmp5_) {
#line 543 "topbar.c"
				BoxesApp* _tmp6_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
				_tmp6_ = boxes_app_app;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
				boxes_app_set_selection_mode (_tmp6_, FALSE);
#line 549 "topbar.c"
			}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			return;
#line 553 "topbar.c"
		}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 557 "topbar.c"
		{
			GtkButton* _tmp7_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp7_ = self->wizard_cancel_btn;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_button_clicked (_tmp7_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			return;
#line 566 "topbar.c"
		}
		default:
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 571 "topbar.c"
	}
}


static void __lambda109_ (BoxesTopbar* self) {
	BoxesTopbarPage _tmp0_ = 0;
	BoxesApp* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = boxes_app_get_selection_mode (_tmp1_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	if (_tmp3_) {
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp0_ = BOXES_TOPBAR_PAGE_SELECTION;
#line 591 "topbar.c"
	} else {
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_COLLECTION);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp0_ = BOXES_TOPBAR_PAGE_COLLECTION;
#line 597 "topbar.c"
	}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_set_page (self, _tmp0_);
#line 601 "topbar.c"
}


static void ___lambda109__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	__lambda109_ ((BoxesTopbar*) self);
#line 608 "topbar.c"
}


static void _boxes_topbar_update_select_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn ((BoxesTopbar*) self);
#line 615 "topbar.c"
}


static void _boxes_topbar_update_select_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn ((BoxesTopbar*) self);
#line 622 "topbar.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 629 "topbar.c"
}


static void _boxes_topbar_update_search_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_search_btn ((BoxesTopbar*) self);
#line 636 "topbar.c"
}


static void _boxes_topbar_update_search_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_search_btn ((BoxesTopbar*) self);
#line 643 "topbar.c"
}


void boxes_topbar_setup_ui (BoxesTopbar* self) {
	const gchar* _tmp0_ = NULL;
	GtkTextDirection _tmp1_ = 0;
	gchar* back_icon = NULL;
	gchar* _tmp2_ = NULL;
	GtkImage* _tmp3_ = NULL;
	GtkImage* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesAppWindow* _tmp6_ = NULL;
	BoxesSearchbar* _tmp7_ = NULL;
	GtkButton* _tmp8_ = NULL;
	BoxesAppWindow* _tmp9_ = NULL;
	BoxesSearchbar* _tmp10_ = NULL;
	GtkButton* _tmp11_ = NULL;
	BoxesAppWindow* _tmp12_ = NULL;
	BoxesSearchbar* _tmp13_ = NULL;
	BoxesApp* _tmp14_ = NULL;
	BoxesApp* _tmp15_ = NULL;
	BoxesCollection* _tmp16_ = NULL;
	BoxesApp* _tmp17_ = NULL;
	BoxesCollection* _tmp18_ = NULL;
	BoxesDisplayToolbar* toolbar = NULL;
	BoxesAppWindow* _tmp19_ = NULL;
	BoxesDisplayPage* _tmp20_ = NULL;
	BoxesDisplayToolbar* _tmp21_ = NULL;
	BoxesDisplayToolbar* _tmp22_ = NULL;
	BoxesDisplayToolbar* _tmp23_ = NULL;
	BoxesDisplayToolbar* _tmp24_ = NULL;
	BoxesApp* _tmp25_ = NULL;
	BoxesCollection* _tmp26_ = NULL;
	BoxesApp* _tmp27_ = NULL;
	BoxesCollection* _tmp28_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = gtk_widget_get_direction ((GtkWidget*) self);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	if (_tmp1_ == GTK_TEXT_DIR_RTL) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp0_ = "go-previous-rtl-symbolic";
#line 687 "topbar.c"
	} else {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp0_ = "go-previous-symbolic";
#line 691 "topbar.c"
	}
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = g_strdup (_tmp0_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	back_icon = _tmp2_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = self->priv->back_image;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_image_set_from_icon_name (_tmp3_, back_icon, GTK_ICON_SIZE_MENU);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = self->priv->props_back_image;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_image_set_from_icon_name (_tmp4_, back_icon, GTK_ICON_SIZE_MENU);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = boxes_app_window;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_vala_assert (_tmp5_ != NULL, "App.window != null");
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp6_ = boxes_app_window;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp7_ = _tmp6_->searchbar;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_vala_assert (_tmp7_ != NULL, "App.window.searchbar != null");
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp8_ = self->priv->search_btn;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp9_ = boxes_app_window;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp10_ = _tmp9_->searchbar;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp8_, "active", (GObject*) _tmp10_, "search-mode-enabled", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp11_ = self->priv->search2_btn;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp12_ = boxes_app_window;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp13_ = _tmp12_->searchbar;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp11_, "active", (GObject*) _tmp13_, "search-mode-enabled", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp14_ = boxes_app_app;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) _tmp14_, "notify::selection-mode", (GCallback) ___lambda109__g_object_notify, self, 0);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn (self);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp15_ = boxes_app_app;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp16_ = _tmp15_->collection;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp16_, "item-added", (GCallback) _boxes_topbar_update_select_btn_boxes_collection_item_added, self, 0);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp17_ = boxes_app_app;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp18_ = _tmp17_->collection;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp18_, "item-removed", (GCallback) _boxes_topbar_update_select_btn_boxes_collection_item_removed, self, 0);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_selection_label (self);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp19_ = boxes_app_window;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp20_ = _tmp19_->display_page;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp21_ = _tmp20_->toolbar;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp22_ = _g_object_ref0 (_tmp21_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	toolbar = _tmp22_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp23_ = self->priv->display_toolbar;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_bind_property_with_closures ((GObject*) toolbar, "title", (GObject*) _tmp23_, "title", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp24_ = self->priv->display_toolbar;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_bind_property_with_closures ((GObject*) toolbar, "subtitle", (GObject*) _tmp24_, "subtitle", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_search_btn (self);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp25_ = boxes_app_app;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp26_ = _tmp25_->collection;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp26_, "item-added", (GCallback) _boxes_topbar_update_search_btn_boxes_collection_item_added, self, 0);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp27_ = boxes_app_app;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp28_ = _tmp27_->collection;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp28_, "item-removed", (GCallback) _boxes_topbar_update_search_btn_boxes_collection_item_removed, self, 0);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (toolbar);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_free0 (back_icon);
#line 787 "topbar.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_ = 0U;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 802 "topbar.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_ = 0;
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 814 "topbar.c"
}


static void boxes_topbar_update_search_btn (BoxesTopbar* self) {
	GtkButton* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GtkButton* _tmp6_ = NULL;
	BoxesApp* _tmp7_ = NULL;
	BoxesCollection* _tmp8_ = NULL;
	GPtrArray* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->search_btn;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_->collection;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_->items;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp6_ = self->priv->search2_btn;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp7_ = boxes_app_app;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp8_ = _tmp7_->collection;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp9_ = _tmp8_->items;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp10_ = g_ptr_array_get_length (_tmp9_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp11_ = _tmp10_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, _tmp11_ != 0);
#line 861 "topbar.c"
}


static void boxes_topbar_update_select_btn (BoxesTopbar* self) {
	GtkButton* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->select_btn;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_->collection;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_->items;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
#line 888 "topbar.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 895 "topbar.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_list_free (self);
#line 904 "topbar.c"
}


static void boxes_topbar_update_selection_label (BoxesTopbar* self) {
	guint items = 0U;
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	guint _tmp5_ = 0U;
	guint _tmp6_ = 0U;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	items = _tmp5_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp6_ = items;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	if (_tmp6_ > ((guint) 0)) {
#line 939 "topbar.c"
		GtkMenuButton* _tmp7_ = NULL;
		guint _tmp8_ = 0U;
		const gchar* _tmp9_ = NULL;
		guint _tmp10_ = 0U;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp7_ = self->priv->selection_menu_button;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp8_ = items;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp9_ = ngettext ("%d selected", "%d selected", (gulong) _tmp8_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp10_ = items;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp11_ = g_strdup_printf (_tmp9_, _tmp10_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp12_ = _tmp11_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		gtk_button_set_label ((GtkButton*) _tmp7_, _tmp12_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_g_free0 (_tmp12_);
#line 962 "topbar.c"
	} else {
		GtkMenuButton* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp13_ = self->priv->selection_menu_button;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp14_ = _ ("(Click on items to select them)");
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		gtk_button_set_label ((GtkButton*) _tmp13_, _tmp14_);
#line 972 "topbar.c"
	}
}


static void boxes_topbar_ui_state_changed (BoxesTopbar* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = _tmp0_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	switch (_tmp1_) {
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 990 "topbar.c"
		{
			GtkButton* _tmp2_ = NULL;
			GtkButton* _tmp3_ = NULL;
			GtkButton* _tmp4_ = NULL;
			GtkButton* _tmp5_ = NULL;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_COLLECTION);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp2_ = self->priv->back_btn;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp2_);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp3_ = self->priv->select_btn;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp3_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp4_ = self->priv->search_btn;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp4_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp5_ = self->priv->new_btn;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp5_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1016 "topbar.c"
		}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_CREDS:
#line 1020 "topbar.c"
		{
			GtkButton* _tmp6_ = NULL;
			GtkButton* _tmp7_ = NULL;
			GtkButton* _tmp8_ = NULL;
			GtkButton* _tmp9_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_COLLECTION);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp6_ = self->priv->new_btn;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp6_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp7_ = self->priv->back_btn;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp7_);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp8_ = self->priv->select_btn;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp8_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp9_ = self->priv->search_btn;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp9_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1046 "topbar.c"
		}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 1050 "topbar.c"
		{
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_DISPLAY);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1056 "topbar.c"
		}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 1060 "topbar.c"
		{
			BoxesApp* _tmp10_ = NULL;
			BoxesCollectionItem* _tmp11_ = NULL;
			GBinding* _tmp12_ = NULL;
			GBinding* _tmp13_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_PROPERTIES);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp10_ = boxes_app_app;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp11_ = _tmp10_->current_item;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp12_ = g_object_bind_property_with_closures ((GObject*) _tmp11_, "name", (GObject*) self, "properties-title", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp13_ = _g_object_ref0 (_tmp12_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			_g_object_unref0 (self->priv->props_name_bind);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			self->priv->props_name_bind = _tmp13_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1082 "topbar.c"
		}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 1086 "topbar.c"
		{
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_WIZARD);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1092 "topbar.c"
		}
		default:
		{
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1098 "topbar.c"
		}
	}
}


static void boxes_topbar_on_new_btn_clicked (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 1112 "topbar.c"
}


static void _boxes_topbar_on_new_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_on_new_btn_clicked ((BoxesTopbar*) self);
#line 1119 "topbar.c"
}


static void boxes_topbar_on_back_btn_clicked (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 1131 "topbar.c"
}


static void _boxes_topbar_on_back_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_on_back_btn_clicked ((BoxesTopbar*) self);
#line 1138 "topbar.c"
}


static void boxes_topbar_on_select_btn_clicked (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_app_set_selection_mode (_tmp0_, TRUE);
#line 1150 "topbar.c"
}


static void _boxes_topbar_on_select_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_on_select_btn_clicked ((BoxesTopbar*) self);
#line 1157 "topbar.c"
}


static void boxes_topbar_on_cancel_btn_clicked (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_app_set_selection_mode (_tmp0_, FALSE);
#line 1169 "topbar.c"
}


static void _boxes_topbar_on_cancel_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_on_cancel_btn_clicked ((BoxesTopbar*) self);
#line 1176 "topbar.c"
}


static void boxes_topbar_on_props_back_btn_clicked (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesUIState _tmp2_ = 0;
	BoxesUIState _tmp3_ = 0;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp1_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, _tmp3_);
#line 1197 "topbar.c"
}


static void _boxes_topbar_on_props_back_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_on_props_back_btn_clicked ((BoxesTopbar*) self);
#line 1204 "topbar.c"
}


BoxesTopbar* boxes_topbar_construct (GType object_type) {
	BoxesTopbar * self = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) g_object_new (object_type, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	return self;
#line 1214 "topbar.c"
}


BoxesTopbar* boxes_topbar_new (void) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	return boxes_topbar_construct (BOXES_TYPE_TOPBAR);
#line 1221 "topbar.c"
}


static BoxesUIState boxes_topbar_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesTopbar* self;
	BoxesUIState _tmp0_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	return result;
#line 1237 "topbar.c"
}


static void boxes_topbar_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesTopbar* self;
	BoxesUIState _tmp0_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 1252 "topbar.c"
}


static BoxesUIState boxes_topbar_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesTopbar* self;
	BoxesUIState _tmp0_ = 0;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->_ui_state;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	return result;
#line 1268 "topbar.c"
}


static void boxes_topbar_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesTopbar* self;
	BoxesUIState _tmp0_ = 0;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->_ui_state = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 1283 "topbar.c"
}


const gchar* boxes_topbar_get_status (BoxesTopbar* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->_status;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	return result;
#line 1298 "topbar.c"
}


void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GtkHeaderBar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	BoxesDisplayToolbar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_free0 (self->_status);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->_status = _tmp1_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = self->priv->collection_toolbar;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = self->_status;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_title (_tmp2_, _tmp3_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = self->priv->display_toolbar;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = self->_status;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_title ((GtkHeaderBar*) _tmp4_, _tmp5_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "status");
#line 1333 "topbar.c"
}


void boxes_topbar_set_properties_title (BoxesTopbar* self, const gchar* value) {
	GtkHeaderBar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesApp* _tmp2_ = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->props_toolbar;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = _ ("%s - Properties");
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = boxes_app_app;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_->current_item;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = boxes_collection_item_get_name (_tmp3_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp6_ = g_strdup_printf (_tmp1_, _tmp5_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp7_ = _tmp6_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_title (_tmp0_, _tmp7_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_free0 (_tmp7_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "properties-title");
#line 1370 "topbar.c"
}


BoxesTopbarPage boxes_topbar_get_page (BoxesTopbar* self) {
	BoxesTopbarPage result;
	BoxesTopbarPage _tmp0_ = 0;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->_page;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	return result;
#line 1385 "topbar.c"
}


void boxes_topbar_set_page (BoxesTopbar* self, BoxesTopbarPage value) {
	BoxesTopbarPage _tmp0_ = 0;
	BoxesTopbarPage _tmp1_ = 0;
	const gchar* _tmp2_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->_page = _tmp0_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = value;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = BOXES_TOPBAR_page_names[_tmp1_];
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp2_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "page");
#line 1407 "topbar.c"
}


static void _boxes_topbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_ui_state_changed ((BoxesTopbar*) self);
#line 1414 "topbar.c"
}


static void _boxes_topbar___lambda126_ (BoxesTopbar* self) {
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_selection_label (self);
#line 1421 "topbar.c"
}


static void __boxes_topbar___lambda126__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_boxes_topbar___lambda126_ ((BoxesTopbar*) self);
#line 1428 "topbar.c"
}


static GObject * boxes_topbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesTopbar * self;
	BoxesApp* _tmp0_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_topbar_parent_class);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_topbar_ui_state_changed_g_object_notify, self, 0);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) _tmp0_, "notify::selected-items", (GCallback) __boxes_topbar___lambda126__g_object_notify, self, 0);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_CROSSFADE);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	return obj;
#line 1453 "topbar.c"
}


static void boxes_topbar_class_init (BoxesTopbarClass * klass) {
	gint BoxesTopbar_private_offset;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesTopbarPrivate));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_topbar_get_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_topbar_set_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_topbar_constructor;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_topbar_finalize;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_STATUS, g_param_spec_string ("status", "status", "status", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_PROPERTIES_TITLE, g_param_spec_string ("properties-title", "properties-title", "properties-title", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_TOPBAR_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	BoxesTopbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/topbar.ui");
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_cancel_btn", FALSE, G_STRUCT_OFFSET (BoxesTopbar, wizard_cancel_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_back_btn", FALSE, G_STRUCT_OFFSET (BoxesTopbar, wizard_back_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_continue_btn", FALSE, G_STRUCT_OFFSET (BoxesTopbar, wizard_continue_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_create_btn", FALSE, G_STRUCT_OFFSET (BoxesTopbar, wizard_create_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props_back_btn", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, props_back_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "search_btn", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, search_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "search2_btn", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, search2_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "select_btn", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, select_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_btn", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, back_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_image", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, back_image));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "new_btn", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, new_btn));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "selection_menu_button", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, selection_menu_button));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "collection_toolbar", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, collection_toolbar));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "display_toolbar", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, display_toolbar));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props_toolbar", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, props_toolbar));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props_back_image", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, props_back_image));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_new_btn_clicked", G_CALLBACK(_boxes_topbar_on_new_btn_clicked_gtk_button_clicked));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_back_btn_clicked", G_CALLBACK(_boxes_topbar_on_back_btn_clicked_gtk_button_clicked));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_select_btn_clicked", G_CALLBACK(_boxes_topbar_on_select_btn_clicked_gtk_button_clicked));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_cancel_btn_clicked", G_CALLBACK(_boxes_topbar_on_cancel_btn_clicked_gtk_button_clicked));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_props_back_btn_clicked", G_CALLBACK(_boxes_topbar_on_props_back_btn_clicked_gtk_button_clicked));
#line 1527 "topbar.c"
}


static void boxes_topbar_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	iface->get_previous_ui_state = boxes_topbar_real_get_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	iface->set_previous_ui_state = boxes_topbar_real_set_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	iface->get_ui_state = boxes_topbar_real_get_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	iface->set_ui_state = boxes_topbar_real_set_ui_state;
#line 1542 "topbar.c"
}


static void boxes_topbar_instance_init (BoxesTopbar * self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv = BOXES_TOPBAR_GET_PRIVATE (self);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_type_ensure (BOXES_TYPE_DISPLAY_TOOLBAR);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1553 "topbar.c"
}


static void boxes_topbar_finalize (GObject* obj) {
	BoxesTopbar * self;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->wizard_cancel_btn);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->wizard_back_btn);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->wizard_continue_btn);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->wizard_create_btn);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->props_back_btn);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->search_btn);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->search2_btn);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->select_btn);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->back_btn);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->back_image);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->new_btn);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->selection_menu_button);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->collection_toolbar);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->display_toolbar);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->props_toolbar);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->props_back_image);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->props_name_bind);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_free0 (self->_status);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (boxes_topbar_parent_class)->finalize (obj);
#line 1599 "topbar.c"
}


GType boxes_topbar_get_type (void) {
	static volatile gsize boxes_topbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_topbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesTopbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_topbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesTopbar), 0, (GInstanceInitFunc) boxes_topbar_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_topbar_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_topbar_type_id;
		boxes_topbar_type_id = g_type_register_static (GTK_TYPE_STACK, "BoxesTopbar", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_topbar_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_topbar_type_id__volatile, boxes_topbar_type_id);
	}
	return boxes_topbar_type_id__volatile;
}


static void _vala_boxes_topbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesTopbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PREVIOUS_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_STATUS:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_value_set_string (value, boxes_topbar_get_status (self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PAGE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_value_set_enum (value, boxes_topbar_get_page (self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 1646 "topbar.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 1652 "topbar.c"
	}
}


static void _vala_boxes_topbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesTopbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PREVIOUS_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_STATUS:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		boxes_topbar_set_status (self, g_value_get_string (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PROPERTIES_TITLE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		boxes_topbar_set_properties_title (self, g_value_get_string (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PAGE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		boxes_topbar_set_page (self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 1692 "topbar.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 1698 "topbar.c"
	}
}



