@define-color boxes_bg_color shade (@theme_bg_color, 0.5);
@define-color boxes_bg2_color mix (@theme_bg_color, @boxes_bg_color, 0.5);
@define-color boxes_selected_color #3465a4;

#CollectionLabel {
    font-size: 11px;
    font-weight: bold;
}

.separator {
    -GtkWidget-wide-separators: true;
    -GtkWidget-separator-height: 1;
}

BoxesMiniGraph {
    background-color: #1d1d1d;
    border-color: #e9e9e9;
    color: #393939;
}

.sidebar {
    background-image: url("icons/boxes-gray.png");
    border-image-repeat: stretch;
    border-style: solid;
    border-width: 0 2px 0 0;
    border-color: #111111;
}

.sidebar GtkTreeView:selected {
    background-color: @boxes_selected_color;
    border-width: 2px 8px 2px 0;
    border-color: transparent;
    border-image-source: url("icons/boxes-arrow.svg");
    border-image-slice: 0 8 0 0;
    border-image-width: 2px 8px 2px 0;
    border-image-repeat: stretch;
    border-style: solid;
}

.sidebar GtkTreeView {
    -GtkTreeView-vertical-separator: 8;
}

.sidebar .cell {
    font-size: 11px;
    font-weight: bold;
}

.boxes-bg {
    background-color: transparent;
    background-image: none;
}

.boxes-property-name-label {
    color: #bebebe;
}

.boxes-machine-name-label {
    color: white;
}

.boxes-step-label {
    color: #989898;
    font-size: 11px;
    font-weight: bold;
}

.boxes-icon-view {
    background-image: url("icons/boxes-dark.png");
    border-image-repeat: stretch;
}

.wizard {
    background-image: url("icons/boxes-dark.png");
    border-image-repeat: stretch;
}

.empty-boxes {
    background-image: url("icons/boxes-dark.png");
    border-image-repeat: stretch;
}

.boxes-wizard-label {
    color: #d8d8d8;
}

.boxes-wizard-summary-prop-name-label {
    color: #bebebe;
}

.boxes-wizard-summary-prop-value-label {
    color: white;
}

.boxes-wizard-summary-customize-button {
    color: white;
}

.boxes-wizard-media-os-label {
    color: #d8d8d8;
    font-weight: bold;
}

.boxes-wizard-current-page-label {
    color: white;
}

.boxes-logo-notice-label {
    color: #989898;
    font-style: italic;
}

.boxes-source-label {
    font-size: 11px;
    font-weight: bold;
}

.boxes-graph-label {
    font-size: 8px;
    font-family: monospace;
    color: #989898;
}

.boxes-source-nb {
    background-color: alpha(#fff, 0.0);
}

.boxes-selected {
    background-color: @boxes_selected_color;
}

.boxes-continue {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (@boxes_selected_color),
                                     to (darker (@boxes_selected_color)));
}

.boxes-continue:insensitive {
    background-image: none;
}

.boxes-product-key-entry {
    font-family: monospace;
}

/* Ensure the viewport is transparent so the background don't
   show through the rounded corners */
.boxes-menu GtkViewport {
    background-image: none;
    background-color: transparent;
    border-style: none;
}

.boxes-menu-row {
    -GtkWidget-focus-line-width: 0;
    border-style: ridge none none none;
    border-color: shade (@boxes_bg2_color, 0.7);
    border-width: 2px 0 0 0;
    box-shadow: none;
    border-image: none;
    background-image: none;
    background-color: @boxes_bg2_color;
    border-radius: 0;
}

.boxes-menu-row:nth-child(first) {
    border-radius: 15px 15px 0 0;
    border-style: none;
}

.boxes-menu-scrolled .boxes-menu-row:nth-child(first) {
    border-radius: 0;
}

.boxes-menu > .boxes-menu-row:nth-child(last) {
    border-radius: 0 0 15px 15px;
}

.boxes-menu-row:prelight, .boxes-menu-row:focus {
    background-color: shade (@boxes_bg2_color, 1.2);
}

.boxes-menu-row:active {
    background-color: @theme_selected_bg_color;
}

.boxes-menu-row *:active {
    color: #ffffff;
}

.boxes-toplevel {
    background-color: @theme_bg_color;
}

.boxes-empty-image {
    color: #2e3436;
    icon-shadow: 0 -1px rgba(0,0,0,0.5);
}

.boxes-empty-details-label {
    color: #555753;
}

.properties {
    background-image: url("icons/boxes-dark.png");
    border-image-repeat: stretch;
}
