/* util-app.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from util-app.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk/gdk.h>
#include <libcommon.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libxml/xpath.h>
#include <osinfo/osinfo.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <config.h>
#include <sys/socket.h>
#include <errno.h>
#include <netinet/in.h>
#include <linux/if.h>
#include <sys/ioctl.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <unistd.h>
#include <cairo.h>
#include <float.h>
#include <math.h>
#include <libgd/gd.h>

#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _gtk_widget_path_unref0(var) ((var == NULL) ? NULL : (var = (gtk_widget_path_unref (var), NULL)))
#define _xmlFreeParserCtxt0(var) ((var == NULL) ? NULL : (var = (xmlFreeParserCtxt (var), NULL)))
#define _xmlXPathFreeContext0(var) ((var == NULL) ? NULL : (var = (xmlXPathFreeContext (var), NULL)))
typedef struct _BoxesCheckSelinuxContextDefaultData BoxesCheckSelinuxContextDefaultData;
typedef struct _BoxesCheckLibvirtKvmData BoxesCheckLibvirtKvmData;
typedef struct _BoxesCheckCpuVtCapabilityData BoxesCheckCpuVtCapabilityData;
typedef struct _BoxesCheckModuleKvmLoadedData BoxesCheckModuleKvmLoadedData;
typedef struct _BoxesCheckStoragePoolData BoxesCheckStoragePoolData;
typedef struct _Block58Data Block58Data;
typedef struct _Block59Data Block59Data;
typedef struct _BoxesCopyFileData BoxesCopyFileData;

#define BOXES_TYPE_CPU_ARCH_COMPATIBILITY (boxes_cpu_arch_compatibility_get_type ())

#define BOXES_FDO_TYPE_TIMEDATE1 (boxes_fdo_timedate1_get_type ())
#define BOXES_FDO_TIMEDATE1(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_FDO_TYPE_TIMEDATE1, BoxesFdotimedate1))
#define BOXES_FDO_IS_TIMEDATE1(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_FDO_TYPE_TIMEDATE1))
#define BOXES_FDO_TIMEDATE1_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_FDO_TYPE_TIMEDATE1, BoxesFdotimedate1Iface))

typedef struct _BoxesFdotimedate1 BoxesFdotimedate1;
typedef struct _BoxesFdotimedate1Iface BoxesFdotimedate1Iface;

#define BOXES_FDO_TYPE_TIMEDATE1_PROXY (boxes_fdo_timedate1_proxy_get_type ())
typedef GDBusProxy BoxesFdotimedate1Proxy;
typedef GDBusProxyClass BoxesFdotimedate1ProxyClass;

struct _BoxesCheckSelinuxContextDefaultData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* diagnosis;
	gboolean result;
	gchar* _tmp0_;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError* _error_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	GError* _vala1__error_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _BoxesCheckLibvirtKvmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar* _tmp4_;
	gchar* kvm;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	GError* _error_;
	GError* _vala1__error_;
	GError* _tmp10_;
	const gchar* _tmp11_;
	GError * _inner_error_;
};

struct _BoxesCheckCpuVtCapabilityData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* file;
	GFile* _tmp0_;
	GFileInputStream* _tmp1_;
	GFile* _tmp2_;
	GFileInputStream* _tmp3_;
	GDataInputStream* stream;
	GDataInputStream* _tmp4_;
	gchar* line;
	gchar* _tmp5_;
	GDataInputStream* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	GError* _error_;
	GError* _tmp13_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckModuleKvmLoadedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* file;
	GFile* _tmp0_;
	GFileInputStream* _tmp1_;
	GFile* _tmp2_;
	GFileInputStream* _tmp3_;
	GDataInputStream* stream;
	GDataInputStream* _tmp4_;
	gchar* line;
	gchar* _tmp5_;
	GDataInputStream* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	GError* _error_;
	GError* _tmp13_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* diagnosis;
	gboolean result;
	gchar* pool_path;
	gchar* _tmp0_;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gchar* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GError* _error_;
	GError* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	gboolean _tmp16_;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	const gchar* _tmp20_;
	gboolean _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	const gchar* _tmp25_;
	gint _tmp26_;
	const gchar* _tmp27_;
	const gchar* _tmp28_;
	gchar* _tmp29_;
	GError * _inner_error_;
};

struct _Block58Data {
	int _ref_count_;
	GtkWidget* widget;
};

struct _Block59Data {
	int _ref_count_;
	BoxesActivityProgress* progress;
	gpointer _async_data_;
};

struct _BoxesCopyFileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GFile* src_file;
	GFile* dest_file;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	Block59Data* _data59_;
	BoxesActivityProgress* _tmp0_;
	GFile* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GFile* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GFile* _tmp7_;
	GFile* _tmp8_;
	GCancellable* _tmp9_;
	GFile* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GFile* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GError* _error_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE = -1,
	BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL = 0,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE = 1,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE = 2
} BoxesCPUArchCompatibility;

struct _BoxesFdotimedate1Iface {
	GTypeInterface parent_iface;
	gchar* (*get_timezone) (BoxesFdotimedate1* self);
	void (*set_timezone) (BoxesFdotimedate1* self, const gchar* value);
};


extern gboolean boxes_libvirt_bridge_net_checked;
gboolean boxes_libvirt_bridge_net_checked = FALSE;
extern gboolean boxes_libvirt_bridge_net_available;
gboolean boxes_libvirt_bridge_net_available = FALSE;

GtkCssProvider* boxes_load_css (const gchar* css);
GdkPixbuf* boxes_load_asset (const gchar* asset, GError** error);
GtkBuilder* boxes_load_ui (const gchar* ui);
void boxes_get_boxes_bg_color (GdkRGBA* result);
void boxes_get_color (const gchar* desc, GdkRGBA* result);
gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error);
void boxes_widget_remove (GtkWidget* widget);
OsinfoDevice* boxes_find_device_by_prop (OsinfoDeviceList* devices, const gchar* prop_name, const gchar* prop_value);
GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size);
void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size);
gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain);
gboolean boxes_is_libvirt_bridge_net_available (void);
static void boxes_check_selinux_context_default_data_free (gpointer _data);
void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis);
static gboolean boxes_check_selinux_context_default_co (BoxesCheckSelinuxContextDefaultData* _data_);
static void boxes_check_selinux_context_default_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_libvirt_kvm_data_free (gpointer _data);
void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_);
static gboolean boxes_check_libvirt_kvm_co (BoxesCheckLibvirtKvmData* _data_);
static void boxes_check_libvirt_kvm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_cpu_vt_capability_data_free (gpointer _data);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_);
static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_module_kvm_loaded_data_free (gpointer _data);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_);
static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_storage_pool_data_free (gpointer _data);
void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis);
static gboolean boxes_check_storage_pool_co (BoxesCheckStoragePoolData* _data_);
static void boxes_check_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf);
static guint8* _vala_array_dup5 (guint8* self, int length);
void boxes_draw_as_css_box (GtkWidget* widget);
static Block58Data* block58_data_ref (Block58Data* _data58_);
static void block58_data_unref (void * _userdata_);
static gboolean __lambda73_ (Block58Data* _data58_, cairo_t* cr);
static gboolean ___lambda73__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
static void boxes_copy_file_data_free (gpointer _data);
void boxes_copy_file (GFile* src_file, GFile* dest_file, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_copy_file_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_copy_file_co (BoxesCopyFileData* _data_);
static Block59Data* block59_data_ref (Block59Data* _data59_);
static void block59_data_unref (void * _userdata_);
static void ___lambda49_ (Block59Data* _data59_, gint64 current, gint64 total);
static void ____lambda49__gfile_progress_callback (gint64 current_num_bytes, gint64 total_num_bytes, gpointer self);
static void boxes_copy_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_cpu_arch_compatibility_get_type (void) G_GNUC_CONST;
BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2);
GType boxes_fdo_timedate1_get_type (void) G_GNUC_CONST;
GType boxes_fdo_timedate1_proxy_get_type (void) G_GNUC_CONST;
guint boxes_fdo_timedate1_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
gchar* boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self);
void boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, const gchar* value);
static void boxes_fdo_timedate1_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static gchar* boxes_fdo_timedate1_dbus_proxy_get_timezone (BoxesFdotimedate1* self);
static void boxes_fdo_timedate1_dbus_proxy_set_timezone (BoxesFdotimedate1* self, const gchar* value);
static void boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init (BoxesFdotimedate1Iface* iface);
static void boxes_fdo_timedate1_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* boxes_fdo_timedate1_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static GVariant* _dbus_boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self);
static gboolean boxes_fdo_timedate1_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, GVariant* _value);
static void _boxes_fdo_timedate1_unregister_object (gpointer user_data);
gchar* boxes_get_timezone (void);
gchar* boxes_get_timezone_from_systemd (GError** error);
gchar* boxes_get_timezone_from_linux (GError** error);
#define BOXES_TZ_FILE "/etc/localtime"
void uuid_generate (guchar* uuid);
void uuid_unparse (guchar* uuid, guchar* output);
gchar* boxes_uuid_generate (void);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static GRegex* _tmp_regex_0 = NULL;
static GRegex* _tmp_regex_1 = NULL;
static const GDBusMethodInfo * const _boxes_fdo_timedate1_dbus_method_info[] = {NULL};
static const GDBusSignalInfo * const _boxes_fdo_timedate1_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _boxes_fdo_timedate1_dbus_property_info_timezone = {-1, "Timezone", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE};
static const GDBusPropertyInfo * const _boxes_fdo_timedate1_dbus_property_info[] = {&_boxes_fdo_timedate1_dbus_property_info_timezone, NULL};
static const GDBusInterfaceInfo _boxes_fdo_timedate1_dbus_interface_info = {-1, "org.freedesktop.timedate1", (GDBusMethodInfo **) (&_boxes_fdo_timedate1_dbus_method_info), (GDBusSignalInfo **) (&_boxes_fdo_timedate1_dbus_signal_info), (GDBusPropertyInfo **) (&_boxes_fdo_timedate1_dbus_property_info)};
static const GDBusInterfaceVTable _boxes_fdo_timedate1_dbus_interface_vtable = {boxes_fdo_timedate1_dbus_interface_method_call, boxes_fdo_timedate1_dbus_interface_get_property, boxes_fdo_timedate1_dbus_interface_set_property};

GtkCssProvider* boxes_load_css (const gchar* css) {
	GtkCssProvider* result = NULL;
	GtkCssProvider* provider = NULL;
	GtkCssProvider* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (css != NULL, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = gtk_css_provider_new ();
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	provider = _tmp0_;
#line 415 "util-app.c"
	{
		GFile* file = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GFile* _tmp4_ = NULL;
		GFile* _tmp5_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = css;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = g_strconcat ("resource:///org/gnome/Boxes/", _tmp1_, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = _tmp2_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = g_file_new_for_uri (_tmp3_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = _tmp4_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp3_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp5_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_css_provider_load_from_file (provider, file, &_inner_error_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (file);
#line 443 "util-app.c"
			goto __catch83_g_error;
		}
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 448 "util-app.c"
	}
	goto __finally83;
	__catch83_g_error:
	{
		GError* e = NULL;
		GError* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		e = _inner_error_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = e;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = _tmp6_->message;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:14: loading css: %s", _tmp7_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 468 "util-app.c"
	}
	__finally83:
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (provider);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 481 "util-app.c"
	}
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = provider;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 487 "util-app.c"
}


GdkPixbuf* boxes_load_asset (const gchar* asset, GError** error) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GdkPixbuf* _tmp4_ = NULL;
	GdkPixbuf* _tmp5_ = NULL;
	GdkPixbuf* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (asset != NULL, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = asset;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strconcat ("/org/gnome/Boxes/icons/", _tmp1_, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = gdk_pixbuf_new_from_resource (_tmp3_, &_inner_error_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp3_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _tmp5_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 523 "util-app.c"
	}
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = _tmp0_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp6_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_tmp0_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 535 "util-app.c"
}


GtkBuilder* boxes_load_ui (const gchar* ui) {
	GtkBuilder* result = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (ui != NULL, NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = gtk_builder_new ();
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	builder = _tmp0_;
#line 550 "util-app.c"
	{
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = ui;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = g_strconcat ("/org/gnome/Boxes/ui/", _tmp1_, NULL, NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = _tmp2_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_builder_add_from_resource (builder, _tmp3_, &_inner_error_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp3_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 567 "util-app.c"
			goto __catch84_g_error;
		}
	}
	goto __finally84;
	__catch84_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		e = _inner_error_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = ui;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = e->message;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error ("util-app.vala:28: Failed to load UI file '%s': %s", _tmp4_, _tmp5_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 589 "util-app.c"
	}
	__finally84:
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (builder);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 602 "util-app.c"
	}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = builder;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 608 "util-app.c"
}


void boxes_get_boxes_bg_color (GdkRGBA* result) {
	GtkStyleContext* style = NULL;
	GtkStyleContext* _tmp0_ = NULL;
	GtkWidgetPath* path = NULL;
	GtkWidgetPath* _tmp1_ = NULL;
	GdkRGBA _tmp2_ = {0};
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = gtk_style_context_new ();
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	style = _tmp0_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gtk_widget_path_new ();
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp1_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_widget_path_append_type (path, GTK_TYPE_WINDOW);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_set_path (style, path);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_add_class (style, "boxes-bg");
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_get_background_color (style, 0, &_tmp2_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = _tmp2_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_gtk_widget_path_unref0 (path);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (style);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 642 "util-app.c"
}


void boxes_get_color (const gchar* desc, GdkRGBA* result) {
	GdkRGBA color = {0};
	const gchar* _tmp0_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (desc != NULL);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	memset (&color, 0, sizeof (GdkRGBA));
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = desc;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gdk_rgba_parse (&color, _tmp0_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = color;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 661 "util-app.c"
}


gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error) {
	gchar* result = NULL;
	xmlParserCtxt* parser = NULL;
	xmlParserCtxt* _tmp0_ = NULL;
	xmlDoc* doc = NULL;
	xmlParserCtxt* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	xmlDoc* _tmp3_ = NULL;
	xmlDoc* _tmp4_ = NULL;
	xmlXPathContext* ctxt = NULL;
	xmlDoc* _tmp6_ = NULL;
	xmlXPathContext* _tmp7_ = NULL;
	xmlXPathObject* obj = NULL;
	xmlXPathContext* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	xmlXPathObject* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	xmlXPathObject* _tmp12_ = NULL;
	xmlXPathObject* _tmp21_ = NULL;
	xmlXPathObjectType _tmp22_ = 0;
	xmlXPathObject* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	GError * _inner_error_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (xmldoc != NULL, NULL);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (xpath != NULL, NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = xmlNewParserCtxt ();
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	parser = _tmp0_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = parser;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = xmldoc;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = xmlCtxtReadDoc (_tmp1_, (xmlChar*) _tmp2_, "doc.xml", NULL, 0);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	doc = _tmp3_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = doc;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp4_ == NULL) {
#line 709 "util-app.c"
		GError* _tmp5_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Can't parse XML doc");
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp5_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_propagate_error (error, _inner_error_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 723 "util-app.c"
		} else {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_clear_error (&_inner_error_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 733 "util-app.c"
		}
	}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = doc;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = xmlXPathNewContext (_tmp6_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	ctxt = _tmp7_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = ctxt;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = xpath;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = xmlXPathEval ((xmlChar*) _tmp9_, _tmp8_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	obj = _tmp10_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = obj;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp12_ == NULL) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = TRUE;
#line 756 "util-app.c"
	} else {
		xmlXPathObject* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = obj;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = _tmp13_->stringval;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = _tmp14_ == NULL;
#line 766 "util-app.c"
	}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp11_) {
#line 770 "util-app.c"
		gboolean _tmp15_ = FALSE;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = required;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp15_) {
#line 776 "util-app.c"
			const gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			GError* _tmp19_ = NULL;
			GError* _tmp20_ = NULL;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp16_ = xpath;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = g_strconcat ("Failed to extract xpath ", _tmp16_, NULL);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = _tmp17_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp19_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp18_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp20_ = _tmp19_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_tmp18_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = _tmp20_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_propagate_error (error, _inner_error_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlFreeParserCtxt0 (parser);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return NULL;
#line 806 "util-app.c"
			} else {
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlFreeParserCtxt0 (parser);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_clear_error (&_inner_error_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return NULL;
#line 818 "util-app.c"
			}
		} else {
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 829 "util-app.c"
		}
	}
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp21_ = obj;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp22_ = _tmp21_->type;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp22_ != XPATH_STRING) {
#line 838 "util-app.c"
		const gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		GError* _tmp26_ = NULL;
		GError* _tmp27_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp23_ = xpath;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp24_ = g_strconcat ("Failed to extract xpath ", _tmp23_, NULL);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp25_ = _tmp24_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp25_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = _tmp26_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp25_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp27_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_propagate_error (error, _inner_error_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 868 "util-app.c"
		} else {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_clear_error (&_inner_error_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 880 "util-app.c"
		}
	}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp28_ = obj;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp29_ = _tmp28_->stringval;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp30_ = g_strdup (_tmp29_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp30_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_xmlXPathFreeContext0 (ctxt);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_xmlFreeParserCtxt0 (parser);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 897 "util-app.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return self ? g_object_ref (self) : NULL;
#line 904 "util-app.c"
}


void boxes_widget_remove (GtkWidget* widget) {
	GtkContainer* container = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkContainer* _tmp2_ = NULL;
	GtkContainer* _tmp3_ = NULL;
	GtkContainer* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (widget != NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = widget;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gtk_widget_get_parent (_tmp0_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GTK_TYPE_CONTAINER) ? ((GtkContainer*) _tmp1_) : NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	container = _tmp2_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = container;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ == NULL) {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (container);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 934 "util-app.c"
	}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = container;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = widget;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_container_remove (_tmp4_, _tmp5_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (container);
#line 944 "util-app.c"
}


OsinfoDevice* boxes_find_device_by_prop (OsinfoDeviceList* devices, const gchar* prop_name, const gchar* prop_value) {
	OsinfoDevice* result = NULL;
	OsinfoFilter* filter = NULL;
	OsinfoFilter* _tmp0_ = NULL;
	OsinfoFilter* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	OsinfoList* filtered = NULL;
	OsinfoDeviceList* _tmp4_ = NULL;
	OsinfoFilter* _tmp5_ = NULL;
	OsinfoList* _tmp6_ = NULL;
	OsinfoList* _tmp7_ = NULL;
	gint _tmp8_ = 0;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (devices != NULL, NULL);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (prop_name != NULL, NULL);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (prop_value != NULL, NULL);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = osinfo_filter_new ();
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	filter = _tmp0_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = filter;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = prop_name;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = prop_value;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	osinfo_filter_add_constraint (_tmp1_, _tmp2_, _tmp3_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = devices;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = filter;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = osinfo_list_new_filtered (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp4_) : NULL, _tmp5_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	filtered = _tmp6_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = filtered;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = osinfo_list_get_length (_tmp7_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp8_ > 0) {
#line 993 "util-app.c"
		OsinfoList* _tmp9_ = NULL;
		OsinfoEntity* _tmp10_ = NULL;
		OsinfoDevice* _tmp11_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = filtered;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = osinfo_list_get_nth (_tmp9_, 0);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, osinfo_device_get_type ()) ? ((OsinfoDevice*) _tmp10_) : NULL);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp11_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filtered);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filter);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1011 "util-app.c"
	} else {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filtered);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filter);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1021 "util-app.c"
	}
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (filtered);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (filter);
#line 1027 "util-app.c"
}


GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size) {
	GtkImage* result = NULL;
	GtkImage* image = NULL;
	GtkImage* _tmp0_ = NULL;
	GtkImage* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	OsinfoOs* _tmp3_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = (GtkImage*) gtk_image_new_from_icon_name ("media-optical", 0);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_ref_sink (_tmp0_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	image = _tmp0_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = image;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = size;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_image_set_pixel_size (_tmp1_, _tmp2_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = os;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ != NULL) {
#line 1054 "util-app.c"
		GtkImage* _tmp4_ = NULL;
		OsinfoOs* _tmp5_ = NULL;
		gint _tmp6_ = 0;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = image;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = os;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = size;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_fetch_os_logo (_tmp4_, _tmp5_, _tmp6_);
#line 1066 "util-app.c"
	}
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = image;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1072 "util-app.c"
}


void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size) {
	gchar* path = NULL;
	OsinfoOs* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (image != NULL);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (os != NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = os;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_strdup (".svg");
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strdup (".png");
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_strdup (".jpg");
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[0] = _tmp1_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[1] = _tmp2_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[2] = _tmp3_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5__length1 = 3;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = boxes_get_logo_path (_tmp0_, _tmp5_, 3);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp7_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = path;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp8_ == NULL) {
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1129 "util-app.c"
	}
	{
		GdkPixbuf* pixbuf = NULL;
		const gchar* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		GdkPixbuf* _tmp11_ = NULL;
		GtkImage* _tmp12_ = NULL;
		GdkPixbuf* _tmp13_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = path;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = size;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = gdk_pixbuf_new_from_file_at_size (_tmp9_, _tmp10_, -1, &_inner_error_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		pixbuf = _tmp11_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1148 "util-app.c"
			goto __catch85_g_error;
		}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = image;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = pixbuf;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_image_set_from_pixbuf (_tmp12_, _tmp13_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pixbuf);
#line 1159 "util-app.c"
	}
	goto __finally85;
	__catch85_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_error_ = _inner_error_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = path;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = _error_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = _tmp15_->message;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:110: Error loading logo file '%s': %s", _tmp14_, _tmp16_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_error_);
#line 1182 "util-app.c"
	}
	__finally85:
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1195 "util-app.c"
	}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (path);
#line 1199 "util-app.c"
}


GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection) {
	GVirStoragePool* result = NULL;
	GVirConnection* _tmp0_ = NULL;
	GVirStoragePool* _tmp1_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = connection;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gvir_connection_find_storage_pool_by_name (_tmp0_, PACKAGE_TARNAME);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp1_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1217 "util-app.c"
}


GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain) {
	GVirStorageVol* result = NULL;
	GVirStoragePool* pool = NULL;
	GVirConnection* _tmp0_ = NULL;
	GVirStoragePool* _tmp1_ = NULL;
	GVirStoragePool* _tmp2_ = NULL;
	GVirStoragePool* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GVirStorageVol* _tmp6_ = NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = connection;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = boxes_get_storage_pool (_tmp0_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pool = _tmp1_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = pool;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == NULL) {
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pool);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1251 "util-app.c"
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = pool;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = domain;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = gvir_storage_pool_get_volume (_tmp3_, _tmp5_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp6_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (pool);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1267 "util-app.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 996 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 997 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 997 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 997 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 997 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 1285 "util-app.c"
}


gboolean boxes_is_libvirt_bridge_net_available (void) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp33_ = FALSE;
	GError * _inner_error_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = boxes_libvirt_bridge_net_checked;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp0_) {
#line 1298 "util-app.c"
		gboolean _tmp1_ = FALSE;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = boxes_libvirt_bridge_net_available;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp1_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1306 "util-app.c"
	}
	{
		gint sock = 0;
		gint _tmp2_ = 0;
		gint _tmp3_ = 0;
		struct ifreq req = {0};
		gchar* if_name = NULL;
		gchar* _tmp7_ = NULL;
		gboolean _tmp19_ = FALSE;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		GFile* file = NULL;
		GFile* _tmp25_ = NULL;
		guint8* contents = NULL;
		gint contents_length1 = 0;
		gint _contents_size_ = 0;
		GFile* _tmp26_ = NULL;
		guint8* _tmp27_ = NULL;
		gsize _tmp28_;
		guint8* _tmp29_ = NULL;
		gint _tmp29__length1 = 0;
		gboolean _tmp30_ = FALSE;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = socket (AF_INET, SOCK_STREAM, 0);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		sock = _tmp2_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = sock;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp3_ < 0) {
#line 1337 "util-app.c"
			gint _tmp4_ = 0;
			gint _tmp5_ = 0;
			GError* _tmp6_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp4_ = errno;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp5_ = g_io_error_from_errno (_tmp4_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp6_ = g_error_new ((GQuark) G_IO_ERROR, _tmp5_, "Failed to create a socket");
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = (GError*) _tmp6_;
#line 1349 "util-app.c"
			goto __catch86_g_error;
		}
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		memset (&req, 0, sizeof (struct ifreq));
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = g_strdup ("virbr0");
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if_name = _tmp7_;
#line 1358 "util-app.c"
		{
			gint i = 0;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			i = 0;
#line 1363 "util-app.c"
			{
				gboolean _tmp8_ = FALSE;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp8_ = TRUE;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				while (TRUE) {
#line 1370 "util-app.c"
					gint _tmp10_ = 0;
					const gchar* _tmp11_ = NULL;
					gint _tmp12_ = 0;
					gint _tmp13_ = 0;
					gint _tmp14_ = 0;
					const gchar* _tmp15_ = NULL;
					gint _tmp16_ = 0;
					gchar _tmp17_ = '\0';
					gchar _tmp18_ = '\0';
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					if (!_tmp8_) {
#line 1382 "util-app.c"
						gint _tmp9_ = 0;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						_tmp9_ = i;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						i = _tmp9_ + 1;
#line 1388 "util-app.c"
					}
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp8_ = FALSE;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp10_ = i;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp11_ = if_name;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp12_ = strlen (_tmp11_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp13_ = _tmp12_;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					if (!(_tmp10_ <= _tmp13_)) {
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						break;
#line 1404 "util-app.c"
					}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp14_ = i;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp15_ = if_name;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp16_ = i;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp17_ = string_get (_tmp15_, (glong) _tmp16_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					req.ifr_name[_tmp14_] = (gchar) _tmp17_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp18_ = req.ifr_name[_tmp14_];
#line 1418 "util-app.c"
				}
			}
		}
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp20_ = sock;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp21_ = ioctl (_tmp20_, SIOCGIFFLAGS, &req);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp21_ < 0) {
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp19_ = TRUE;
#line 1430 "util-app.c"
		} else {
			struct ifreq _tmp22_ = {0};
			gshort _tmp23_ = 0;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp22_ = req;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp23_ = _tmp22_.ifr_flags;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp19_ = !((_tmp23_ & IFF_UP) == IFF_UP);
#line 1440 "util-app.c"
		}
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp19_) {
#line 1444 "util-app.c"
			const gchar* _tmp24_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp24_ = if_name;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_debug ("util-app.vala:149: Interface '%s' is either not available or not up.", _tmp24_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = FALSE;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (if_name);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			 (&req);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 1458 "util-app.c"
		}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp25_ = g_file_new_for_path ("/etc/qemu/bridge.conf");
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp25_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = file;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_file_load_contents (_tmp26_, NULL, &_tmp27_, &_tmp28_, NULL, &_inner_error_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents = (g_free (contents), NULL);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents = _tmp27_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents_length1 = _tmp28_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_contents_size_ = contents_length1;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents = (g_free (contents), NULL);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (file);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (if_name);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			 (&req);
#line 1486 "util-app.c"
			goto __catch86_g_error;
		}
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp29_ = contents;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp29__length1 = contents_length1;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp30_ = g_regex_match_simple ("^allow.*virbr0", (const gchar*) _tmp29_, 0, 0);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_libvirt_bridge_net_available = _tmp30_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents = (g_free (contents), NULL);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (if_name);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		 (&req);
#line 1505 "util-app.c"
	}
	goto __finally86;
	__catch86_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_error_ = _inner_error_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp31_ = _error_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp32_ = _tmp31_->message;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:161: %s", _tmp32_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_libvirt_bridge_net_available = FALSE;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_error_);
#line 1527 "util-app.c"
	}
	__finally86:
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 1538 "util-app.c"
	}
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_libvirt_bridge_net_checked = TRUE;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp33_ = boxes_libvirt_bridge_net_available;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp33_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1548 "util-app.c"
}


gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1) {
	gchar* result = NULL;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar* path = NULL;
	OsinfoOs* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GFile* file = NULL;
	const gchar* _tmp10_ = NULL;
	GFile* _tmp11_ = NULL;
	GFile* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	GFile* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = extensions;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0__length1 = extensions_length1;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp0__length1 == 0) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1586 "util-app.c"
	}
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = os;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp1_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = extensions;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4__length1 = extensions_length1;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_[0];
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = g_strconcat (_tmp3_, _tmp5_, NULL);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = boxes_get_pixmap (_tmp7_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp7_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp9_;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = path;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = g_file_new_for_path (_tmp10_);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	file = _tmp11_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = file;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = g_file_query_exists (_tmp12_, NULL);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_tmp13_) {
#line 1624 "util-app.c"
		OsinfoOs* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		gchar** _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		GFile* _tmp23_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = os;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = osinfo_os_get_distro (_tmp14_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = _tmp15_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17_ = extensions;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17__length1 = extensions_length1;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp18_ = _tmp17_[0];
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp19_ = g_strconcat (_tmp16_, _tmp18_, NULL);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp20_ = _tmp19_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp21_ = boxes_get_pixmap (_tmp20_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		path = _tmp21_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp20_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp22_ = path;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp23_ = g_file_new_for_path (_tmp22_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp23_;
#line 1668 "util-app.c"
	}
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp24_ = file;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp25_ = g_file_query_exists (_tmp24_, NULL);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp25_) {
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = path;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1682 "util-app.c"
	} else {
		OsinfoOs* _tmp26_ = NULL;
		gchar** _tmp27_ = NULL;
		gint _tmp27__length1 = 0;
		gchar** _tmp28_ = NULL;
		gint _tmp28__length1 = 0;
		gchar* _tmp29_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = os;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = extensions;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27__length1 = extensions_length1;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28_ = extensions;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28__length1 = extensions_length1;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp29_ = boxes_get_logo_path (_tmp26_, _tmp27_ + 1, _tmp28__length1 - 1);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp29_;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 1710 "util-app.c"
	}
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (file);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (path);
#line 1716 "util-app.c"
}


static void boxes_check_selinux_context_default_data_free (gpointer _data) {
	BoxesCheckSelinuxContextDefaultData* _data_;
	_data_ = _data;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckSelinuxContextDefaultData, _data_);
#line 1725 "util-app.c"
}


void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckSelinuxContextDefaultData);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_selinux_context_default);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_selinux_context_default_data_free);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_selinux_context_default_co (_data_);
#line 1739 "util-app.c"
}


gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis) {
	gboolean result;
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (diagnosis) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*diagnosis = _data_->diagnosis;
#line 1752 "util-app.c"
	} else {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->diagnosis);
#line 1756 "util-app.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->diagnosis = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 1764 "util-app.c"
}


static void boxes_check_selinux_context_default_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_selinux_context_default_co (_data_);
#line 1778 "util-app.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 964 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 964 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 965 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		separator = "";
#line 1795 "util-app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 1805 "util-app.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 1815 "util-app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 1821 "util-app.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == (-1)) {
#line 1832 "util-app.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 1844 "util-app.c"
		} else {
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 1848 "util-app.c"
		}
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 1852 "util-app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1856 "util-app.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp62_ = NULL;
#line 969 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 1879 "util-app.c"
		{
			gboolean _tmp9_ = FALSE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			i = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 1888 "util-app.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 1901 "util-app.c"
					gint _tmp10_ = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 1907 "util-app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != (-1)) {
#line 1917 "util-app.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 1929 "util-app.c"
				} else {
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 1933 "util-app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 1939 "util-app.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == (-1)) {
#line 1950 "util-app.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 1965 "util-app.c"
					} else {
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 1969 "util-app.c"
					}
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 1973 "util-app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					break;
#line 1979 "util-app.c"
				}
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 1991 "util-app.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 2012 "util-app.c"
				} else {
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 2016 "util-app.c"
				}
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 2022 "util-app.c"
			}
		}
#line 973 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 973 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 2029 "util-app.c"
			gchar* _tmp32_ = NULL;
#line 974 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 974 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 974 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			return result;
#line 2037 "util-app.c"
		}
#line 976 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 976 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 976 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 979 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 979 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 979 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 2075 "util-app.c"
		{
			gboolean _tmp46_ = FALSE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			i = 1;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 2084 "util-app.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp60_ = NULL;
				void* _tmp61_ = NULL;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 2100 "util-app.c"
					gint _tmp47_ = 0;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 2106 "util-app.c"
				}
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					break;
#line 2120 "util-app.c"
				}
#line 982 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 982 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 982 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 982 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 2140 "util-app.c"
					gchar** _tmp57_ = NULL;
					gint _tmp57__length1 = 0;
					gint _tmp58_ = 0;
					const gchar* _tmp59_ = NULL;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 2155 "util-app.c"
				} else {
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 2159 "util-app.c"
				}
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 2167 "util-app.c"
			}
		}
#line 986 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 986 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		res = NULL;
#line 986 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 986 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		return result;
#line 2178 "util-app.c"
	} else {
		gchar* _tmp63_ = NULL;
#line 988 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 988 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 988 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		return result;
#line 2187 "util-app.c"
	}
}


static gboolean boxes_check_selinux_context_default_co (BoxesCheckSelinuxContextDefaultData* _data_) {
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 2197 "util-app.c"
		goto _state_0;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 2201 "util-app.c"
		goto _state_1;
		default:
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 2206 "util-app.c"
	}
	_state_0:
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->diagnosis);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->diagnosis = _data_->_tmp0_;
#line 2217 "util-app.c"
	{
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("restorecon");
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_strdup ("-nrv");
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = boxes_get_user_pkgconfig (NULL);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = boxes_get_user_pkgdata (NULL);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = boxes_get_user_pkgcache (NULL);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = g_new0 (gchar*, 5 + 1);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[0] = _data_->_tmp1_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[1] = _data_->_tmp2_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[2] = _data_->_tmp3_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[3] = _data_->_tmp4_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[4] = _data_->_tmp5_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp6_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 5;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7__length1 = 0;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->argv;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7__length1 = _data_->argv_length1;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp7_, _data_->_tmp7__length1, NULL, boxes_check_selinux_context_default_ready, _data_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2279 "util-app.c"
		_state_1:
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp8_, NULL, &_data_->_inner_error_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp8_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 2295 "util-app.c"
				goto __catch87_g_spawn_error_noexec;
			}
			goto __catch87_g_error;
		}
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->standard_output;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = 0;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = strlen (_data_->_tmp9_);
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = 0;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_tmp11_ == 0) {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->result = TRUE;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_state_ == 0) {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2324 "util-app.c"
			} else {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2328 "util-app.c"
			}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_unref (_data_->_async_result);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 2334 "util-app.c"
		}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12__length1 = 0;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->argv;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12__length1 = _data_->argv_length1;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = g_strdup ("-r");
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp12_[1]);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_[1] = _data_->_tmp13_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp12_[1];
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = _ ("Your SELinux context looks incorrect, you can try to fix it by running" \
":\n" \
"%s");
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16__length1 = 0;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = _data_->argv;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16__length1 = _data_->argv_length1;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = _vala_g_strjoinv (" ", _data_->_tmp16_, _data_->_tmp16__length1);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = _data_->_tmp17_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = g_strdup_printf (_data_->_tmp15_, _data_->_tmp18_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp19_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp18_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2396 "util-app.c"
		} else {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2400 "util-app.c"
		}
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2406 "util-app.c"
	}
	goto __finally87;
	__catch87_g_spawn_error_noexec:
	{
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp20_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp20_ = _ ("SELinux not installed?");
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp21_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = TRUE;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2435 "util-app.c"
		} else {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2439 "util-app.c"
		}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2445 "util-app.c"
	}
	goto __finally87;
	__catch87_g_error:
	{
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = NULL;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = _data_->_vala1__error_;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = NULL;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:215: %s", _data_->_tmp23_);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 2466 "util-app.c"
	}
	__finally87:
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2477 "util-app.c"
	}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = FALSE;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2485 "util-app.c"
	} else {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2489 "util-app.c"
	}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2499 "util-app.c"
	} else {
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2503 "util-app.c"
	}
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 2509 "util-app.c"
}


static void boxes_check_libvirt_kvm_data_free (gpointer _data) {
	BoxesCheckLibvirtKvmData* _data_;
	_data_ = _data;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckLibvirtKvmData, _data_);
#line 2518 "util-app.c"
}


void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckLibvirtKvmData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckLibvirtKvmData);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_libvirt_kvm);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_libvirt_kvm_data_free);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_libvirt_kvm_co (_data_);
#line 2532 "util-app.c"
}


gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckLibvirtKvmData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2545 "util-app.c"
}


static void boxes_check_libvirt_kvm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckLibvirtKvmData* _data_;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_libvirt_kvm_co (_data_);
#line 2559 "util-app.c"
}


static gboolean boxes_check_libvirt_kvm_co (BoxesCheckLibvirtKvmData* _data_) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 2568 "util-app.c"
		goto _state_0;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 2572 "util-app.c"
		goto _state_1;
		default:
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 2577 "util-app.c"
	}
	_state_0:
	{
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = NULL;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = g_strdup ("virsh");
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("capabilities");
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_[0] = _data_->_tmp0_;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_[1] = _data_->_tmp1_;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp2_;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 2;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3__length1 = 0;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->argv;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3__length1 = _data_->argv_length1;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp3_, _data_->_tmp3__length1, NULL, boxes_check_libvirt_kvm_ready, _data_);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2623 "util-app.c"
		_state_1:
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp4_, NULL, &_data_->_inner_error_);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp4_;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 2639 "util-app.c"
				goto __catch88_g_spawn_error_noexec;
			}
			goto __catch88_g_error;
		}
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->standard_output;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = boxes_extract_xpath (_data_->_tmp5_, "string(/capabilities/guest[os_type='hvm']/arch/domain[@type='kvm']/emu" \
"lator)", FALSE, &_data_->_inner_error_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->kvm = _data_->_tmp6_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 2662 "util-app.c"
				goto __catch88_g_spawn_error_noexec;
			}
			goto __catch88_g_error;
		}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->kvm;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = 0;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = strlen (_data_->_tmp7_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = 0;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = _data_->_tmp9_ != 0;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->kvm);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2691 "util-app.c"
		} else {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2695 "util-app.c"
		}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2701 "util-app.c"
	}
	goto __finally88;
	__catch88_g_spawn_error_noexec:
	{
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("util-app.vala:232: libvirt is not installed correctly");
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 2714 "util-app.c"
	}
	goto __finally88;
	__catch88_g_error:
	{
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->_vala1__error_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_->message;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:234: %s", _data_->_tmp11_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 2735 "util-app.c"
	}
	__finally88:
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2746 "util-app.c"
	}
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = FALSE;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2754 "util-app.c"
	} else {
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2758 "util-app.c"
	}
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2768 "util-app.c"
	} else {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2772 "util-app.c"
	}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 2778 "util-app.c"
}


static void boxes_check_cpu_vt_capability_data_free (gpointer _data) {
	BoxesCheckCpuVtCapabilityData* _data_;
	_data_ = _data;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckCpuVtCapabilityData, _data_);
#line 2787 "util-app.c"
}


void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckCpuVtCapabilityData);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_cpu_vt_capability);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_cpu_vt_capability_data_free);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 2801 "util-app.c"
}


gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckCpuVtCapabilityData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2814 "util-app.c"
}


static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 2828 "util-app.c"
}


static inline GRegex* _thread_safe_regex_init (GRegex** re, const gchar * pattern, GRegexMatchFlags match_options) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_once_init_enter ((volatile gsize*) re)) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		GRegex* val = g_regex_new (pattern, match_options, 0, NULL);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_once_init_leave ((volatile gsize*) re, (gsize) val);
#line 2839 "util-app.c"
	}
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return *re;
#line 2843 "util-app.c"
}


static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 2852 "util-app.c"
		goto _state_0;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 2856 "util-app.c"
		goto _state_1;
		default:
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 2861 "util-app.c"
	}
	_state_0:
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_result_ = FALSE;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/cpuinfo");
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->file = _data_->_tmp0_;
#line 2872 "util-app.c"
	{
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _data_->file;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_file_read (_data_->_tmp2_, NULL, &_data_->_inner_error_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->_tmp3_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2886 "util-app.c"
			goto __catch89_g_error;
		}
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp1_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->stream = _data_->_tmp4_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->line = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		while (TRUE) {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp6_ = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp6_ = _data_->stream;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_state_ = 1;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_data_input_stream_read_line_async (_data_->_tmp6_, G_PRIORITY_DEFAULT, NULL, boxes_check_cpu_vt_capability_ready, _data_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 2909 "util-app.c"
			_state_1:
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = g_data_input_stream_read_line_finish (_data_->_tmp6_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp5_ = _data_->_tmp7_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->line);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->stream);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->_tmp1_);
#line 2925 "util-app.c"
				goto __catch89_g_error;
			}
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = _data_->_tmp5_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp5_ = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->line);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->line = _data_->_tmp8_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = _data_->line;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (!(_data_->_tmp9_ != NULL)) {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->_tmp5_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 2948 "util-app.c"
			}
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = _data_->line;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = FALSE;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_0, "^flags.*(vmx|svm)", 0), _data_->_tmp10_, 0, NULL);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_result_ = _data_->_tmp11_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = FALSE;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = _data_->_result_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_tmp12_) {
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->_tmp5_);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 2970 "util-app.c"
			}
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->_tmp5_);
#line 2974 "util-app.c"
		}
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->line);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->stream);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp1_);
#line 2982 "util-app.c"
	}
	goto __finally89;
	__catch89_g_error:
	{
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = _data_->_error_;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp13_->message;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:253: Failed to read file /proc/cpuinfo: %s", _data_->_tmp14_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 3003 "util-app.c"
	}
	__finally89:
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->file);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3016 "util-app.c"
	}
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = FALSE;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = NULL;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = NULL;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = g_strconcat ("check_cpu_vt_capability: ", _data_->_tmp17_, NULL);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = NULL;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:256: %s", _data_->_tmp19_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp19_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp17_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_result_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3052 "util-app.c"
	} else {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3056 "util-app.c"
	}
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3068 "util-app.c"
	} else {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3072 "util-app.c"
	}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3078 "util-app.c"
}


static void boxes_check_module_kvm_loaded_data_free (gpointer _data) {
	BoxesCheckModuleKvmLoadedData* _data_;
	_data_ = _data;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckModuleKvmLoadedData, _data_);
#line 3087 "util-app.c"
}


void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckModuleKvmLoadedData);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_module_kvm_loaded);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_module_kvm_loaded_data_free);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 3101 "util-app.c"
}


gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckModuleKvmLoadedData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3114 "util-app.c"
}


static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 3128 "util-app.c"
}


static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3137 "util-app.c"
		goto _state_0;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3141 "util-app.c"
		goto _state_1;
		default:
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3146 "util-app.c"
	}
	_state_0:
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_result_ = FALSE;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/modules");
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->file = _data_->_tmp0_;
#line 3157 "util-app.c"
	{
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _data_->file;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_file_read (_data_->_tmp2_, NULL, &_data_->_inner_error_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->_tmp3_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 3171 "util-app.c"
			goto __catch90_g_error;
		}
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp1_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->stream = _data_->_tmp4_;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->line = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		while (TRUE) {
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp6_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp6_ = _data_->stream;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_state_ = 1;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_data_input_stream_read_line_async (_data_->_tmp6_, G_PRIORITY_DEFAULT, NULL, boxes_check_module_kvm_loaded_ready, _data_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 3194 "util-app.c"
			_state_1:
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = g_data_input_stream_read_line_finish (_data_->_tmp6_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp5_ = _data_->_tmp7_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->line);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->stream);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->_tmp1_);
#line 3210 "util-app.c"
				goto __catch90_g_error;
			}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = _data_->_tmp5_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp5_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->line);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->line = _data_->_tmp8_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = _data_->line;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (!(_data_->_tmp9_ != NULL)) {
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->_tmp5_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3233 "util-app.c"
			}
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = _data_->line;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = FALSE;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_1, "^(kvm_intel|kvm_amd)", 0), _data_->_tmp10_, 0, NULL);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_result_ = _data_->_tmp11_;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = FALSE;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = _data_->_result_;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_tmp12_) {
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->_tmp5_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3255 "util-app.c"
			}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->_tmp5_);
#line 3259 "util-app.c"
		}
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->line);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->stream);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp1_);
#line 3267 "util-app.c"
	}
	goto __finally90;
	__catch90_g_error:
	{
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = _data_->_error_;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp13_->message;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:273: Failed to read file /proc/modules: %s", _data_->_tmp14_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 3288 "util-app.c"
	}
	__finally90:
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->file);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3301 "util-app.c"
	}
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = FALSE;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = g_strconcat ("check_module_kvm_loaded: ", _data_->_tmp17_, NULL);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:276: %s", _data_->_tmp19_);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp19_);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp17_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_result_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3337 "util-app.c"
	} else {
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3341 "util-app.c"
	}
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3353 "util-app.c"
	} else {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3357 "util-app.c"
	}
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3363 "util-app.c"
}


static void boxes_check_storage_pool_data_free (gpointer _data) {
	BoxesCheckStoragePoolData* _data_;
	_data_ = _data;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckStoragePoolData, _data_);
#line 3372 "util-app.c"
}


void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckStoragePoolData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckStoragePoolData);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_storage_pool);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_storage_pool_data_free);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_storage_pool_co (_data_);
#line 3386 "util-app.c"
}


gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis) {
	gboolean result;
	BoxesCheckStoragePoolData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (diagnosis) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*diagnosis = _data_->diagnosis;
#line 3399 "util-app.c"
	} else {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->diagnosis);
#line 3403 "util-app.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->diagnosis = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3411 "util-app.c"
}


static void boxes_check_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckStoragePoolData* _data_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_storage_pool_co (_data_);
#line 3425 "util-app.c"
}


static gboolean boxes_check_storage_pool_co (BoxesCheckStoragePoolData* _data_) {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3434 "util-app.c"
		goto _state_0;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3438 "util-app.c"
		goto _state_1;
		default:
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3443 "util-app.c"
	}
	_state_0:
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->diagnosis);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->diagnosis = _data_->_tmp0_;
#line 3454 "util-app.c"
	{
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("virsh");
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_strdup ("pool-dumpxml");
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_strdup (PACKAGE_TARNAME);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[0] = _data_->_tmp1_;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[1] = _data_->_tmp2_;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[2] = _data_->_tmp3_;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp4_;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 3;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5__length1 = 0;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->argv;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5__length1 = _data_->argv_length1;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp5_, _data_->_tmp5__length1, NULL, boxes_check_storage_pool_ready, _data_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3504 "util-app.c"
		_state_1:
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp6_, NULL, &_data_->_inner_error_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp6_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 3518 "util-app.c"
			goto __catch91_g_error;
		}
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = _data_->standard_output;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = boxes_extract_xpath (_data_->_tmp8_, "string(/pool[@type='dir']/target/path)", FALSE, &_data_->_inner_error_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->_tmp9_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 3537 "util-app.c"
			goto __catch91_g_error;
		}
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->_tmp7_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->pool_path = _data_->_tmp10_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp7_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 3556 "util-app.c"
	}
	goto __finally91;
	__catch91_g_error:
	{
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_error_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->_tmp11_->message;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:291: %s", _data_->_tmp12_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = _ ("Could not get 'gnome-boxes' storage pool information from libvirt. Mak" \
"e sure 'virsh -c qemu:///session pool-dumpxml gnome-boxes' is working.");
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = g_strdup (_data_->_tmp13_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp14_;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3597 "util-app.c"
		} else {
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3601 "util-app.c"
		}
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3607 "util-app.c"
	}
	__finally91:
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3620 "util-app.c"
	}
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = NULL;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->pool_path;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = FALSE;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = g_file_test (_data_->_tmp15_, G_FILE_TEST_EXISTS);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_data_->_tmp16_) {
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but this director" \
"y does not exist");
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = _data_->pool_path;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = g_strdup_printf (_data_->_tmp17_, _data_->_tmp18_);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp19_;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3656 "util-app.c"
		} else {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3660 "util-app.c"
		}
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3666 "util-app.c"
	}
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = NULL;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = _data_->pool_path;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp21_ = FALSE;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp21_ = g_file_test (_data_->_tmp20_, G_FILE_TEST_IS_DIR);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_data_->_tmp21_) {
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but is not a dire" \
"ctory");
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = _data_->pool_path;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp24_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp24_ = g_strdup_printf (_data_->_tmp22_, _data_->_tmp23_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp24_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3702 "util-app.c"
		} else {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3706 "util-app.c"
		}
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3712 "util-app.c"
	}
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp25_ = NULL;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp25_ = _data_->pool_path;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp26_ = 0;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp26_ = access (_data_->_tmp25_, (R_OK | W_OK) | X_OK);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_tmp26_ != 0) {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp27_ = NULL;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp27_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but is not user-r" \
"eadable/writable");
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp28_ = NULL;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp28_ = _data_->pool_path;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp29_ = NULL;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp29_ = g_strdup_printf (_data_->_tmp27_, _data_->_tmp28_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp29_;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3748 "util-app.c"
		} else {
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3752 "util-app.c"
		}
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3758 "util-app.c"
	}
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = TRUE;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3768 "util-app.c"
	} else {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3772 "util-app.c"
	}
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3784 "util-app.c"
	} else {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3788 "util-app.c"
	}
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3794 "util-app.c"
}


static guint8* _vala_array_dup5 (guint8* self, int length) {
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return g_memdup (self, length * sizeof (guint8));
#line 3801 "util-app.c"
}


GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf) {
	GdkPixbuf* result = NULL;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static const guint8 ALPHA_TRESHOLD = (guint8) 50;
#line 3809 "util-app.c"
	gboolean _tmp0_ = FALSE;
	GdkPixbuf* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	GdkPixbuf* _tmp5_ = NULL;
	gint width = 0;
	GdkPixbuf* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gint height = 0;
	GdkPixbuf* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint rowstride = 0;
	GdkPixbuf* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	guint8* orig_pixels = NULL;
	GdkPixbuf* _tmp12_ = NULL;
	guint8* _tmp13_ = NULL;
	gint orig_pixels_length1 = 0;
	gint _orig_pixels_size_ = 0;
	guint8* pixels = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	guint8* _tmp16_ = NULL;
	gint pixels_length1 = 0;
	gint _pixels_size_ = 0;
	guint8* _tmp62_ = NULL;
	gint _tmp62__length1 = 0;
	guint8* _tmp63_ = NULL;
	gint _tmp63__length1 = 0;
	GdkPixbuf* _tmp64_ = NULL;
	GdkColorspace _tmp65_ = 0;
	gint _tmp66_ = 0;
	gint _tmp67_ = 0;
	gint _tmp68_ = 0;
	GdkPixbuf* _tmp69_ = NULL;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = pixbuf;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = gdk_pixbuf_get_n_channels (_tmp1_);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == 4) {
#line 3852 "util-app.c"
		GdkPixbuf* _tmp3_ = NULL;
		gint _tmp4_ = 0;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = pixbuf;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = gdk_pixbuf_get_bits_per_sample (_tmp3_);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp4_ == 8;
#line 3861 "util-app.c"
	} else {
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = FALSE;
#line 3865 "util-app.c"
	}
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = pixbuf;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (_tmp0_, _tmp5_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = pixbuf;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = gdk_pixbuf_get_width (_tmp6_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	width = _tmp7_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = pixbuf;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = gdk_pixbuf_get_height (_tmp8_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	height = _tmp9_;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = pixbuf;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = gdk_pixbuf_get_rowstride (_tmp10_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	rowstride = _tmp11_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = pixbuf;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = gdk_pixbuf_get_pixels (_tmp12_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	orig_pixels = _tmp13_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	orig_pixels_length1 = -1;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_orig_pixels_size_ = orig_pixels_length1;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = rowstride;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = height;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp16_ = g_new0 (guint8, _tmp14_ * _tmp15_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels = _tmp16_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels_length1 = _tmp14_ * _tmp15_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_pixels_size_ = pixels_length1;
#line 3911 "util-app.c"
	{
		gint i = 0;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		i = 0;
#line 3916 "util-app.c"
		{
			gboolean _tmp17_ = FALSE;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = TRUE;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			while (TRUE) {
#line 3923 "util-app.c"
				gint _tmp19_ = 0;
				gint _tmp20_ = 0;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (!_tmp17_) {
#line 3928 "util-app.c"
					gint _tmp18_ = 0;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp18_ = i;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					i = _tmp18_ + 1;
#line 3934 "util-app.c"
				}
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp17_ = FALSE;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp19_ = i;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp20_ = height;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (!(_tmp19_ < _tmp20_)) {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					break;
#line 3946 "util-app.c"
				}
				{
					gint j = 0;
					gint k = 0;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					j = 0;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					k = 0;
#line 3955 "util-app.c"
					{
						gboolean _tmp21_ = FALSE;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						_tmp21_ = TRUE;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						while (TRUE) {
#line 3962 "util-app.c"
							gint _tmp24_ = 0;
							gint _tmp25_ = 0;
							gint orig_index = 0;
							gint _tmp26_ = 0;
							gint _tmp27_ = 0;
							gint _tmp28_ = 0;
							gint index = 0;
							gint _tmp29_ = 0;
							gint _tmp30_ = 0;
							gint _tmp31_ = 0;
							guint8* _tmp32_ = NULL;
							gint _tmp32__length1 = 0;
							gint _tmp33_ = 0;
							guint8 _tmp34_ = 0U;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (!_tmp21_) {
#line 3979 "util-app.c"
								gint _tmp22_ = 0;
								gint _tmp23_ = 0;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp22_ = j;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								j = _tmp22_ + 4;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp23_ = k;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								k = _tmp23_ + 3;
#line 3990 "util-app.c"
							}
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp21_ = FALSE;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp24_ = j;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp25_ = width;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (!(_tmp24_ < (_tmp25_ * 4))) {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								break;
#line 4002 "util-app.c"
							}
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp26_ = rowstride;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp27_ = i;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp28_ = j;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							orig_index = (_tmp26_ * _tmp27_) + _tmp28_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp29_ = rowstride;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp30_ = i;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp31_ = k;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							index = (_tmp29_ * _tmp30_) + _tmp31_;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp32_ = orig_pixels;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp32__length1 = orig_pixels_length1;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp33_ = orig_index;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp34_ = _tmp32_[_tmp33_ + 3];
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (_tmp34_ < ALPHA_TRESHOLD) {
#line 4030 "util-app.c"
								guint8* _tmp35_ = NULL;
								gint _tmp35__length1 = 0;
								gint _tmp36_ = 0;
								guint8 _tmp37_ = 0U;
								guint8* _tmp38_ = NULL;
								gint _tmp38__length1 = 0;
								gint _tmp39_ = 0;
								guint8 _tmp40_ = 0U;
								guint8* _tmp41_ = NULL;
								gint _tmp41__length1 = 0;
								gint _tmp42_ = 0;
								guint8 _tmp43_ = 0U;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp35_ = pixels;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp35__length1 = pixels_length1;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp36_ = index;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp35_[_tmp36_] = (guint8) 0xFF;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp37_ = _tmp35_[_tmp36_];
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38_ = pixels;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38__length1 = pixels_length1;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp39_ = index;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38_[_tmp39_ + 1] = (guint8) 0xFF;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp40_ = _tmp38_[_tmp39_ + 1];
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41_ = pixels;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41__length1 = pixels_length1;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp42_ = index;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41_[_tmp42_ + 2] = (guint8) 0xFF;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp43_ = _tmp41_[_tmp42_ + 2];
#line 4073 "util-app.c"
							} else {
								guint8* _tmp44_ = NULL;
								gint _tmp44__length1 = 0;
								gint _tmp45_ = 0;
								guint8* _tmp46_ = NULL;
								gint _tmp46__length1 = 0;
								gint _tmp47_ = 0;
								guint8 _tmp48_ = 0U;
								guint8 _tmp49_ = 0U;
								guint8* _tmp50_ = NULL;
								gint _tmp50__length1 = 0;
								gint _tmp51_ = 0;
								guint8* _tmp52_ = NULL;
								gint _tmp52__length1 = 0;
								gint _tmp53_ = 0;
								guint8 _tmp54_ = 0U;
								guint8 _tmp55_ = 0U;
								guint8* _tmp56_ = NULL;
								gint _tmp56__length1 = 0;
								gint _tmp57_ = 0;
								guint8* _tmp58_ = NULL;
								gint _tmp58__length1 = 0;
								gint _tmp59_ = 0;
								guint8 _tmp60_ = 0U;
								guint8 _tmp61_ = 0U;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44_ = pixels;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44__length1 = pixels_length1;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp45_ = index;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp46_ = orig_pixels;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp46__length1 = orig_pixels_length1;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp47_ = orig_index;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp48_ = _tmp46_[_tmp47_];
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44_[_tmp45_] = _tmp48_;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp49_ = _tmp44_[_tmp45_];
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp50_ = pixels;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp50__length1 = pixels_length1;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp51_ = index;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp52_ = orig_pixels;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp52__length1 = orig_pixels_length1;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp53_ = orig_index;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp54_ = _tmp52_[_tmp53_ + 1];
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp50_[_tmp51_ + 1] = _tmp54_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp55_ = _tmp50_[_tmp51_ + 1];
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp56_ = pixels;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp56__length1 = pixels_length1;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp57_ = index;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp58_ = orig_pixels;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp58__length1 = orig_pixels_length1;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp59_ = orig_index;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp60_ = _tmp58_[_tmp59_ + 2];
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp56_[_tmp57_ + 2] = _tmp60_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp61_ = _tmp56_[_tmp57_ + 2];
#line 4153 "util-app.c"
							}
						}
					}
				}
			}
		}
	}
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp62_ = pixels;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp62__length1 = pixels_length1;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp63_ = (_tmp62_ != NULL) ? _vala_array_dup5 (_tmp62_, _tmp62__length1) : ((gpointer) _tmp62_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp63__length1 = _tmp62__length1;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp64_ = pixbuf;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp65_ = gdk_pixbuf_get_colorspace (_tmp64_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp66_ = width;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp67_ = height;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp68_ = rowstride;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp69_ = gdk_pixbuf_new_from_data (_tmp63_, _tmp65_, FALSE, 8, _tmp66_, _tmp67_, _tmp68_, (GdkPixbufDestroyNotify) NULL, NULL);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp69_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels = (g_free (pixels), NULL);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4187 "util-app.c"
}


static Block58Data* block58_data_ref (Block58Data* _data58_) {
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data58_->_ref_count_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data58_;
#line 4196 "util-app.c"
}


static void block58_data_unref (void * _userdata_) {
	Block58Data* _data58_;
	_data58_ = (Block58Data*) _userdata_;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data58_->_ref_count_)) {
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data58_->widget);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block58Data, _data58_);
#line 4209 "util-app.c"
	}
}


static gboolean __lambda73_ (Block58Data* _data58_, cairo_t* cr) {
	gboolean result = FALSE;
	GtkStyleContext* context = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkStyleContext* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkAllocation allocation = {0};
	GtkWidget* _tmp3_ = NULL;
	GtkAllocation _tmp4_ = {0};
	cairo_t* _tmp5_ = NULL;
	GtkAllocation _tmp6_ = {0};
	gint _tmp7_ = 0;
	GtkAllocation _tmp8_ = {0};
	gint _tmp9_ = 0;
	cairo_t* _tmp10_ = NULL;
	GtkAllocation _tmp11_ = {0};
	gint _tmp12_ = 0;
	GtkAllocation _tmp13_ = {0};
	gint _tmp14_ = 0;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (cr != NULL, FALSE);
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _data58_->widget;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gtk_widget_get_style_context (_tmp0_);
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	context = _tmp2_;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _data58_->widget;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_widget_get_allocation (_tmp3_, &_tmp4_);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	allocation = _tmp4_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = cr;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = allocation;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_.width;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = allocation;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_.height;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_render_background (context, _tmp5_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp7_, (gdouble) _tmp9_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = cr;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = allocation;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = _tmp11_.width;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = allocation;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = _tmp13_.height;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_render_frame (context, _tmp10_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp12_, (gdouble) _tmp14_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = FALSE;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (context);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4279 "util-app.c"
}


static gboolean ___lambda73__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda73_ (self, cr);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4288 "util-app.c"
}


void boxes_draw_as_css_box (GtkWidget* widget) {
	Block58Data* _data58_;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (widget != NULL);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data58_ = g_slice_new0 (Block58Data);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data58_->_ref_count_ = 1;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = widget;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data58_->widget);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data58_->widget = _tmp1_;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data58_->widget;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_signal_connect_data (_tmp2_, "draw", (GCallback) ___lambda73__gtk_widget_draw, block58_data_ref (_data58_), (GClosureNotify) block58_data_unref, 0);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	block58_data_unref (_data58_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data58_ = NULL;
#line 4319 "util-app.c"
}


static void boxes_copy_file_data_free (gpointer _data) {
	BoxesCopyFileData* _data_;
	_data_ = _data;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->src_file);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->dest_file);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCopyFileData, _data_);
#line 4334 "util-app.c"
}


void boxes_copy_file (GFile* src_file, GFile* dest_file, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCopyFileData* _data_;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	BoxesActivityProgress* _tmp4_ = NULL;
	BoxesActivityProgress* _tmp5_ = NULL;
	GCancellable* _tmp6_ = NULL;
	GCancellable* _tmp7_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCopyFileData);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_copy_file);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_copy_file_data_free);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = src_file;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->src_file);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->src_file = _tmp1_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = dest_file;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->dest_file);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->dest_file = _tmp3_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = progress;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->progress);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->progress = _tmp5_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = cancellable;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->cancellable = _tmp7_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_copy_file_co (_data_);
#line 4388 "util-app.c"
}


void boxes_copy_file_finish (GAsyncResult* _res_, GError** error) {
	BoxesCopyFileData* _data_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 4398 "util-app.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4402 "util-app.c"
}


static Block59Data* block59_data_ref (Block59Data* _data59_) {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data59_->_ref_count_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data59_;
#line 4411 "util-app.c"
}


static void block59_data_unref (void * _userdata_) {
	Block59Data* _data59_;
	_data59_ = (Block59Data*) _userdata_;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data59_->_ref_count_)) {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data59_->progress);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block59Data, _data59_);
#line 4424 "util-app.c"
	}
}


static void ___lambda49_ (Block59Data* _data59_, gint64 current, gint64 total) {
	BoxesActivityProgress* _tmp0_ = NULL;
	gint64 _tmp1_ = 0LL;
	gint64 _tmp2_ = 0LL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _data59_->progress;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = current;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = total;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_activity_progress_set_progress (_tmp0_, ((gdouble) _tmp1_) / _tmp2_);
#line 4441 "util-app.c"
}


static void ____lambda49__gfile_progress_callback (gint64 current_num_bytes, gint64 total_num_bytes, gpointer self) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	___lambda49_ (self, current_num_bytes, total_num_bytes);
#line 4448 "util-app.c"
}


static void boxes_copy_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCopyFileData* _data_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_copy_file_co (_data_);
#line 4462 "util-app.c"
}


static gboolean boxes_copy_file_co (BoxesCopyFileData* _data_) {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 4471 "util-app.c"
		goto _state_0;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 4475 "util-app.c"
		goto _state_1;
		default:
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 4480 "util-app.c"
	}
	_state_0:
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_data59_ = g_slice_new0 (Block59Data);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_data59_->_ref_count_ = 1;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = _data_->progress;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->_data59_->progress);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_data59_->progress = _data_->_tmp0_;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_data59_->_async_data_ = _data_;
#line 4497 "util-app.c"
	{
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->src_file;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_file_get_path (_data_->_tmp1_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = _data_->dest_file;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = g_file_get_path (_data_->_tmp4_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:372: Copying '%s' to '%s'..", _data_->_tmp3_, _data_->_tmp6_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp6_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp3_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->src_file;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = _data_->dest_file;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->cancellable;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_file_copy_async (_data_->_tmp7_, _data_->_tmp8_, 0, G_PRIORITY_DEFAULT, _data_->_tmp9_, ____lambda49__gfile_progress_callback, _data_->_data59_, boxes_copy_file_ready, _data_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4547 "util-app.c"
		_state_1:
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_file_copy_finish (_data_->_tmp7_, _data_->_res_, &_data_->_inner_error_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_EXISTS)) {
#line 4555 "util-app.c"
				goto __catch92_g_io_error_exists;
			}
			goto __finally92;
		}
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->src_file;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = g_file_get_path (_data_->_tmp10_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->_tmp11_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = _data_->dest_file;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = g_file_get_path (_data_->_tmp13_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = _data_->_tmp14_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:376: Copied '%s' to '%s'.", _data_->_tmp12_, _data_->_tmp15_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp15_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp12_);
#line 4590 "util-app.c"
	}
	goto __finally92;
	__catch92_g_io_error_exists:
	{
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 4601 "util-app.c"
	}
	__finally92:
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		block59_data_unref (_data_->_data59_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_data59_ = NULL;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4618 "util-app.c"
		} else {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4622 "util-app.c"
		}
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4628 "util-app.c"
	}
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	block59_data_unref (_data_->_data59_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_data59_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4638 "util-app.c"
	} else {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4642 "util-app.c"
	}
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 4648 "util-app.c"
}


GType boxes_cpu_arch_compatibility_get_type (void) {
	static volatile gsize boxes_cpu_arch_compatibility_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_cpu_arch_compatibility_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE, "BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE", "incompatible"}, {BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL, "BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL", "identical"}, {BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE, "BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE", "compatible"}, {BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE, "BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE", "compatible-diff-wordsize"}, {0, NULL, NULL}};
		GType boxes_cpu_arch_compatibility_type_id;
		boxes_cpu_arch_compatibility_type_id = g_enum_register_static ("BoxesCPUArchCompatibility", values);
		g_once_init_leave (&boxes_cpu_arch_compatibility_type_id__volatile, boxes_cpu_arch_compatibility_type_id);
	}
	return boxes_cpu_arch_compatibility_type_id__volatile;
}


BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2) {
	BoxesCPUArchCompatibility result = 0;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GQuark _tmp3_ = 0U;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label0 = 0;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label1 = 0;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label2 = 0;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label3 = 0;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label4 = 0;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (arch1 != NULL, 0);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (arch2 != NULL, 0);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = arch2;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _tmp0_;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("i386")))) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4693 "util-app.c"
			default:
			{
				const gchar* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
				GQuark _tmp7_ = 0U;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label0 = 0;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label1 = 0;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label2 = 0;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label3 = 0;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label4 = 0;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp4_ = arch1;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp5_ = _tmp4_;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp7_ = (NULL == _tmp5_) ? 0 : g_quark_from_string (_tmp5_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp7_ == ((0 != _tmp6_label0) ? _tmp6_label0 : (_tmp6_label0 = g_quark_from_static_string ("i386")))) {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4719 "util-app.c"
						default:
						{
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4726 "util-app.c"
						}
					}
				} else if (((_tmp7_ == ((0 != _tmp6_label1) ? _tmp6_label1 : (_tmp6_label1 = g_quark_from_static_string ("i486")))) || (_tmp7_ == ((0 != _tmp6_label2) ? _tmp6_label2 : (_tmp6_label2 = g_quark_from_static_string ("i586"))))) || (_tmp7_ == ((0 != _tmp6_label3) ? _tmp6_label3 : (_tmp6_label3 = g_quark_from_static_string ("i686"))))) {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4732 "util-app.c"
						default:
						{
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4739 "util-app.c"
						}
					}
				} else if (_tmp7_ == ((0 != _tmp6_label4) ? _tmp6_label4 : (_tmp6_label4 = g_quark_from_static_string ("x86_64")))) {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4745 "util-app.c"
						default:
						{
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4752 "util-app.c"
						}
					}
				} else {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4758 "util-app.c"
						default:
						{
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4765 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("i486")))) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4774 "util-app.c"
			default:
			{
				const gchar* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
				GQuark _tmp11_ = 0U;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label0 = 0;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label1 = 0;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label2 = 0;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label3 = 0;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp8_ = arch1;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp9_ = _tmp8_;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp11_ = (NULL == _tmp9_) ? 0 : g_quark_from_string (_tmp9_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp11_ == ((0 != _tmp10_label0) ? _tmp10_label0 : (_tmp10_label0 = g_quark_from_static_string ("i486")))) {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4798 "util-app.c"
						default:
						{
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4805 "util-app.c"
						}
					}
				} else if ((_tmp11_ == ((0 != _tmp10_label1) ? _tmp10_label1 : (_tmp10_label1 = g_quark_from_static_string ("i586")))) || (_tmp11_ == ((0 != _tmp10_label2) ? _tmp10_label2 : (_tmp10_label2 = g_quark_from_static_string ("i686"))))) {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4811 "util-app.c"
						default:
						{
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4818 "util-app.c"
						}
					}
				} else if (_tmp11_ == ((0 != _tmp10_label3) ? _tmp10_label3 : (_tmp10_label3 = g_quark_from_static_string ("x86_64")))) {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4824 "util-app.c"
						default:
						{
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4831 "util-app.c"
						}
					}
				} else {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4837 "util-app.c"
						default:
						{
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4844 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("i586")))) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4853 "util-app.c"
			default:
			{
				const gchar* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				GQuark _tmp15_ = 0U;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label0 = 0;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label1 = 0;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label2 = 0;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp12_ = arch1;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp13_ = _tmp12_;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp15_ = (NULL == _tmp13_) ? 0 : g_quark_from_string (_tmp13_);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp15_ == ((0 != _tmp14_label0) ? _tmp14_label0 : (_tmp14_label0 = g_quark_from_static_string ("i586")))) {
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4875 "util-app.c"
						default:
						{
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4882 "util-app.c"
						}
					}
				} else if (_tmp15_ == ((0 != _tmp14_label1) ? _tmp14_label1 : (_tmp14_label1 = g_quark_from_static_string ("i686")))) {
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4888 "util-app.c"
						default:
						{
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4895 "util-app.c"
						}
					}
				} else if (_tmp15_ == ((0 != _tmp14_label2) ? _tmp14_label2 : (_tmp14_label2 = g_quark_from_static_string ("x86_64")))) {
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4901 "util-app.c"
						default:
						{
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4908 "util-app.c"
						}
					}
				} else {
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4914 "util-app.c"
						default:
						{
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4921 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("i686")))) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4930 "util-app.c"
			default:
			{
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				GQuark _tmp19_ = 0U;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp18_label0 = 0;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp18_label1 = 0;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp16_ = arch1;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp17_ = _tmp16_;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp19_ = (NULL == _tmp17_) ? 0 : g_quark_from_string (_tmp17_);
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp19_ == ((0 != _tmp18_label0) ? _tmp18_label0 : (_tmp18_label0 = g_quark_from_static_string ("i686")))) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4950 "util-app.c"
						default:
						{
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4957 "util-app.c"
						}
					}
				} else if (_tmp19_ == ((0 != _tmp18_label1) ? _tmp18_label1 : (_tmp18_label1 = g_quark_from_static_string ("x86_64")))) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4963 "util-app.c"
						default:
						{
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4970 "util-app.c"
						}
					}
				} else {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 4976 "util-app.c"
						default:
						{
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 4983 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string ("x86_64")))) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 4992 "util-app.c"
			default:
			{
				const gchar* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				GQuark _tmp23_ = 0U;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp22_label0 = 0;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp20_ = arch1;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp21_ = _tmp20_;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp23_ = (NULL == _tmp21_) ? 0 : g_quark_from_string (_tmp21_);
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp23_ == ((0 != _tmp22_label0) ? _tmp22_label0 : (_tmp22_label0 = g_quark_from_static_string ("x86_64")))) {
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5010 "util-app.c"
						default:
						{
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5017 "util-app.c"
						}
					}
				} else {
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5023 "util-app.c"
						default:
						{
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5030 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == g_quark_from_string (OSINFO_ARCHITECTURE_ALL)) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5039 "util-app.c"
			default:
			{
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return result;
#line 5046 "util-app.c"
			}
		}
	} else {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5052 "util-app.c"
			default:
			{
				const gchar* _tmp24_ = NULL;
				const gchar* _tmp25_ = NULL;
				GQuark _tmp27_ = 0U;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp24_ = arch1;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp25_ = _tmp24_;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp27_ = (NULL == _tmp25_) ? 0 : g_quark_from_string (_tmp25_);
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp27_ == g_quark_from_string (OSINFO_ARCHITECTURE_ALL)) {
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5068 "util-app.c"
						default:
						{
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5075 "util-app.c"
						}
					}
				} else {
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5081 "util-app.c"
						default:
						{
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5088 "util-app.c"
						}
					}
				}
			}
		}
	}
}


gchar* boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self) {
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return BOXES_FDO_TIMEDATE1_GET_INTERFACE (self)->get_timezone (self);
#line 5103 "util-app.c"
}


void boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, const gchar* value) {
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (self != NULL);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	BOXES_FDO_TIMEDATE1_GET_INTERFACE (self)->set_timezone (self, value);
#line 5112 "util-app.c"
}


static void boxes_fdo_timedate1_base_init (BoxesFdotimedate1Iface * iface) {
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static gboolean initialized = FALSE;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!initialized) {
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		initialized = TRUE;
#line 5123 "util-app.c"
	}
}


GType boxes_fdo_timedate1_get_type (void) {
	static volatile gsize boxes_fdo_timedate1_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_fdo_timedate1_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesFdotimedate1Iface), (GBaseInitFunc) boxes_fdo_timedate1_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType boxes_fdo_timedate1_type_id;
		boxes_fdo_timedate1_type_id = g_type_register_static (G_TYPE_INTERFACE, "BoxesFdotimedate1", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (boxes_fdo_timedate1_type_id, G_TYPE_OBJECT);
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) boxes_fdo_timedate1_proxy_get_type);
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.timedate1");
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) boxes_fdo_timedate1_register_object);
		g_once_init_leave (&boxes_fdo_timedate1_type_id__volatile, boxes_fdo_timedate1_type_id);
	}
	return boxes_fdo_timedate1_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (BoxesFdotimedate1Proxy, boxes_fdo_timedate1_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BOXES_FDO_TYPE_TIMEDATE1, boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init) )
static void boxes_fdo_timedate1_proxy_class_init (BoxesFdotimedate1ProxyClass* klass) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_DBUS_PROXY_CLASS (klass)->g_signal = boxes_fdo_timedate1_proxy_g_signal;
#line 5148 "util-app.c"
}


static void boxes_fdo_timedate1_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
}


static void boxes_fdo_timedate1_proxy_init (BoxesFdotimedate1Proxy* self) {
}


static gchar* boxes_fdo_timedate1_dbus_proxy_get_timezone (BoxesFdotimedate1* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Timezone");
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 5167 "util-app.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.timedate1"));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Timezone"));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 5185 "util-app.c"
		}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 5191 "util-app.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 5199 "util-app.c"
}


static void boxes_fdo_timedate1_dbus_proxy_set_timezone (BoxesFdotimedate1* self, const gchar* value) {
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.timedate1"));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Timezone"));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (value));
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_close (&_arguments_builder);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_arguments = g_variant_builder_end (&_arguments_builder);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!_reply) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5227 "util-app.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_reply);
#line 5231 "util-app.c"
}


static void boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init (BoxesFdotimedate1Iface* iface) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	iface->get_timezone = boxes_fdo_timedate1_dbus_proxy_get_timezone;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	iface->set_timezone = boxes_fdo_timedate1_dbus_proxy_set_timezone;
#line 5240 "util-app.c"
}


static void boxes_fdo_timedate1_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (invocation);
#line 5251 "util-app.c"
}


static GVariant* _dbus_boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self) {
	gchar* result;
	GVariant* _reply;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_timedate1_get_timezone (self);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5266 "util-app.c"
}


static GVariant* boxes_fdo_timedate1_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (strcmp (property_name, "Timezone") == 0) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_timedate1_get_timezone (object);
#line 5279 "util-app.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return NULL;
#line 5283 "util-app.c"
}


static void _dbus_boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, GVariant* _value) {
	gchar* value = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	value = g_variant_dup_string (_value, NULL);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_fdo_timedate1_set_timezone (self, value);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (value);
#line 5295 "util-app.c"
}


static gboolean boxes_fdo_timedate1_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (strcmp (property_name, "Timezone") == 0) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_dbus_boxes_fdo_timedate1_set_timezone (object, value);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return TRUE;
#line 5310 "util-app.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5314 "util-app.c"
}


guint boxes_fdo_timedate1_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data = g_new (gpointer, 3);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[0] = g_object_ref (object);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[1] = g_object_ref (connection);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[2] = g_strdup (path);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_boxes_fdo_timedate1_dbus_interface_info), &_boxes_fdo_timedate1_dbus_interface_vtable, data, _boxes_fdo_timedate1_unregister_object, error);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!result) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return 0;
#line 5335 "util-app.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5339 "util-app.c"
}


static void _boxes_fdo_timedate1_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[0]);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[1]);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (data[2]);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (data);
#line 5354 "util-app.c"
}


gchar* boxes_get_timezone (void) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
	{
		gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = boxes_get_timezone_from_systemd (&_inner_error_);
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp1_;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5371 "util-app.c"
			goto __catch93_g_error;
		}
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = _tmp0_;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = NULL;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp2_;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp0_);
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 5384 "util-app.c"
	}
	goto __finally93;
	__catch93_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		e = _inner_error_;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = e;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp3_->message;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:466: Failed to get timezone from systemd: %s", _tmp4_);
#line 5402 "util-app.c"
		{
			gchar* _tmp5_ = NULL;
			gchar* _tmp6_ = NULL;
			gchar* _tmp7_ = NULL;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp6_ = boxes_get_timezone_from_linux (&_inner_error_);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp5_ = _tmp6_;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5413 "util-app.c"
				goto __catch94_g_error;
			}
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp7_ = _tmp5_;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp5_ = NULL;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = _tmp7_;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_tmp5_);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 5428 "util-app.c"
		}
		goto __finally94;
		__catch94_g_error:
		{
			GError* e = NULL;
			GError* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			e = _inner_error_;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = NULL;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp8_ = e;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp9_ = _tmp8_->message;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_warning ("util-app.vala:470: Failed to find system timezone: %s", _tmp9_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 5454 "util-app.c"
		}
		__finally94:
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5467 "util-app.c"
	}
	__finally93:
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_clear_error (&_inner_error_);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return NULL;
#line 5476 "util-app.c"
}


gchar* boxes_get_timezone_from_systemd (GError** error) {
	gchar* result = NULL;
	BoxesFdotimedate1* timedate = NULL;
	BoxesFdotimedate1* _tmp0_ = NULL;
	BoxesFdotimedate1* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	BoxesFdotimedate1* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GError * _inner_error_ = NULL;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_initable_new (BOXES_FDO_TYPE_TIMEDATE1_PROXY, NULL, &_inner_error_, "g-flags", 0, "g-name", "org.freedesktop.timedate1", "g-bus-type", G_BUS_TYPE_SYSTEM, "g-object-path", "/org/freedesktop/timedate1", "g-interface-name", "org.freedesktop.timedate1", NULL);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	timedate = (BoxesFdotimedate1*) _tmp0_;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5503 "util-app.c"
	}
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = timedate;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = boxes_fdo_timedate1_get_timezone (_tmp1_);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = _tmp3_;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_ == NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp4_);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_) {
#line 5519 "util-app.c"
		GError* _tmp6_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Failed to get timezone from systemd");
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp6_;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (timedate);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5531 "util-app.c"
	}
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = timedate;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = boxes_fdo_timedate1_get_timezone (_tmp7_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp9_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (timedate);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 5545 "util-app.c"
}


gchar* boxes_get_timezone_from_linux (GError** error) {
	gchar* result = NULL;
	GFile* file = NULL;
	GFile* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GFileInfo* info = NULL;
	GFileInfo* _tmp3_ = NULL;
	gchar* target = NULL;
	GFileInfo* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar** tokens = NULL;
	const gchar* _tmp9_ = NULL;
	gchar** _tmp10_ = NULL;
	gchar** _tmp11_ = NULL;
	gint tokens_length1 = 0;
	gint _tokens_size_ = 0;
	gboolean _tmp12_ = FALSE;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gchar** _tmp17_ = NULL;
	gint _tmp17__length1 = 0;
	const gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	GError * _inner_error_ = NULL;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_file_new_for_path (BOXES_TZ_FILE);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	file = _tmp0_;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_file_query_exists (file, NULL);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_tmp1_) {
#line 5583 "util-app.c"
		GError* _tmp2_ = NULL;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file not found in expected location '%s'", BOXES_TZ_FILE);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp2_;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5595 "util-app.c"
	}
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &_inner_error_);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	info = _tmp3_;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5609 "util-app.c"
	}
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = info;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = g_file_info_get_symlink_target (_tmp4_);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	target = _tmp6_;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = target;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp7_ == NULL) {
#line 5623 "util-app.c"
		GError* _tmp8_ = NULL;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file '%s' is expected to be a symlink", BOXES_TZ_FILE);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp8_;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (target);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (info);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5639 "util-app.c"
	}
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = target;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = _tmp10_ = g_strsplit (_tmp9_, "zoneinfo/", 0);
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens = _tmp11_;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens_length1 = _vala_array_length (_tmp10_);
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tokens_size_ = tokens_length1;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = tokens;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13__length1 = tokens_length1;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp13_ == NULL) {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = TRUE;
#line 5659 "util-app.c"
	} else {
		gchar** _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = tokens;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14__length1 = tokens_length1;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = _tmp14__length1 < 2;
#line 5669 "util-app.c"
	}
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp12_) {
#line 5673 "util-app.c"
		const gchar* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = target;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file in unexpected location '%s'", _tmp15_);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp16_;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (target);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (info);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 5694 "util-app.c"
	}
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp17_ = tokens;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp17__length1 = tokens_length1;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp18_ = _tmp17_[1];
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp19_ = g_strdup (_tmp18_);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp19_;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (target);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (info);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (file);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 5716 "util-app.c"
}


gchar* boxes_uuid_generate (void) {
	gchar* result = NULL;
	guchar* udn = NULL;
	guchar* _tmp0_ = NULL;
	gint udn_length1 = 0;
	gint _udn_size_ = 0;
	guchar* id = NULL;
	guchar* _tmp1_ = NULL;
	gint id_length1 = 0;
	gint _id_size_ = 0;
	gchar* _tmp2_ = NULL;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_new0 (guchar, 50);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn = _tmp0_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn_length1 = 50;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_udn_size_ = udn_length1;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_new0 (guchar, 16);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = _tmp1_;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id_length1 = 16;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_id_size_ = id_length1;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	uuid_generate (id);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	uuid_unparse (id, udn);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strdup ((const gchar*) udn);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp2_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = (g_free (id), NULL);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn = (g_free (udn), NULL);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 5761 "util-app.c"
}


GIcon* boxes_create_symbolic_emblem (const gchar* name) {
	GIcon* result = NULL;
	GIcon* pix = NULL;
	const gchar* _tmp0_ = NULL;
	GIcon* _tmp1_ = NULL;
	GIcon* _tmp2_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = name;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gd_create_symbolic_icon (_tmp0_, 128);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pix = _tmp1_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = pix;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == NULL) {
#line 5783 "util-app.c"
		const gchar* _tmp3_ = NULL;
		GThemedIcon* _tmp4_ = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = name;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = (GThemedIcon*) g_themed_icon_new (_tmp3_);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pix);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		pix = (GIcon*) _tmp4_;
#line 5794 "util-app.c"
	}
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = pix;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 5800 "util-app.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 5807 "util-app.c"
		int i;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 5815 "util-app.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 5827 "util-app.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 5840 "util-app.c"
		}
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 5845 "util-app.c"
}



